# -*- rpm-spec -*-

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward.
%define min_rhel 8
%define min_fedora 33

%define arches_qemu_kvm         %{ix86} x86_64 %{power64} %{arm} aarch64 s390x
%if 0%{?rhel}
    %if 0%{?rhel} > 8
        %define arches_qemu_kvm     x86_64 aarch64 s390x
    %else
        %define arches_qemu_kvm     x86_64 %{power64} aarch64 s390x
    %endif
%endif

%define arches_64bit            x86_64 %{power64} aarch64 s390x riscv64
%define arches_x86              %{ix86} x86_64

%define arches_systemtap_64bit  %{arches_64bit}
%define arches_dmidecode        %{arches_x86}
%define arches_xen              %{arches_x86} aarch64
%define arches_vbox             %{arches_x86}
%define arches_ceph             %{arches_64bit}
%define arches_zfs              %{arches_x86} %{power64} %{arm}
%define arches_numactl          %{arches_x86} %{power64} aarch64
%define arches_numad            %{arches_x86} %{power64} aarch64

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

%ifarch %{arches_qemu_kvm}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%define with_qemu_tcg      %{with_qemu}

# RHEL disables TCG on all architectures
%if 0%{?rhel}
    %define with_qemu_tcg 0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%if 0%{?fedora}
    %define with_storage_sheepdog 0%{!?_without_storage_sheepdog:1}
%else
    %define with_storage_sheepdog 0
%endif

%define with_storage_gluster 0%{!?_without_storage_gluster:1}
%if 0%{?rhel}
    # Glusterfs has been dropped in RHEL-9, and before that
    # was only enabled on arches where KVM exists
    %if 0%{?rhel} > 8
        %define with_storage_gluster 0
    %else
        %ifnarch %{arches_qemu_kvm}
            %define with_storage_gluster 0
        %endif
    %endif
%endif

# Fedora has zfs-fuse
%if 0%{?fedora}
    %define with_storage_zfs      0%{!?_without_storage_zfs:1}
%else
    %define with_storage_zfs      0
%endif

%define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
# libiscsi has been dropped in RHEL-9
%if 0%{?rhel} > 8
    %define with_storage_iscsi_direct 0
%endif

# Other optional features
%define with_numactl          0%{!?_without_numactl:1}

# A few optional bits off by default, we enable later
%define with_fuse             0
%define with_sanlock          0
%define with_numad            0
%define with_firewalld_zone   0
%define with_netcf            0
%define with_libssh2          0
%define with_wireshark        0
%define with_libssh           0
%define with_dmidecode        0

# Finally set the OS / architecture specific special cases

# Architecture-dependent features
%ifnarch %{arches_xen}
    %define with_libxl 0
%endif
%ifnarch %{arches_vbox}
    %define with_vbox 0
%endif
%ifnarch %{arches_numactl}
    %define with_numactl 0
%endif
%ifnarch %{arches_zfs}
    %define with_storage_zfs 0
%endif
#ifnarch %{arches_ceph}
    %define with_storage_rbd 0
#endif

# RHEL doesn't ship many hypervisor drivers
%if 0%{?rhel}
    %define with_openvz 0
    %define with_vbox 0
    %define with_vmware 0
    %define with_libxl 0
    %define with_hyperv 0
    %define with_vz 0
    %define with_lxc 0
%endif

%define with_firewalld_zone 0%{!?_without_firewalld_zone:1}

%if 0%{?_aci_build:1}
    %define with_vz 0
    %define with_vzct 0
    %define with_vcmmd 0
    %define with_storage_vstorage 0
    %define with_secret 0
    %define with_storage_misc 0
    %define with_lxc 0
    %define with_storage_rbd 0
    %define with_storage_gluster 0
    %define with_storage_zfs 0
    %define with_storage_sheepdog 0
    %define with_storage_iscsi_direct  0
%else
    %define with_vz 1
    %define with_vzct 1
    %define with_vcmmd 1
    %define with_storage_vstorage 1
    %define with_secret 1
    %define with_storage_misc 1
    %define with_lxc 1
%endif

%if (0%{?fedora} && 0%{?fedora} < 34) || (0%{?rhel} && 0%{?rhel} < 9)
    %define with_netcf 0%{!?_without_netcf:1}
%endif


# fuse is used to provide virtualized /proc for LXC
%if %{with_lxc}
    %define with_fuse      0%{!?_without_fuse:1}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on arches where kvm is available for RHEL
%if 0%{?fedora}
    %define with_sanlock 0%{!?_without_sanlock:1}
%endif
%if 0%{?rhel}
    %ifarch %{arches_qemu_kvm}
        %define with_sanlock 0%{!?_without_sanlock:1}
    %endif
%endif

%if 0%{?_aci_build:1}
    %define with_sanlock 0
%endif

# Enable libssh2 transport for new enough distros
%if 0%{?fedora}
    %define with_libssh2 0%{!?_without_libssh2:1}
%endif

# Enable wireshark plugins for all distros
%define with_wireshark 0%{!?_without_wireshark:0}
%define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan

# Enable libssh transport for all distros
%define with_libssh 0%{!?_without_libssh:1}

%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifarch %{arches_numad}
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

%ifarch %{arches_dmidecode}
    %define with_dmidecode 0%{!?_without_dmidecode:1}
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu


# RHEL releases provide stable tool chains and so it is safe to turn
# compiler warning into errors without being worried about frequent
# changes in reported warnings
%if 0%{?rhel}
    %define enable_werror -Dwerror=true
%else
    %define enable_werror -Dwerror=false -Dgit_werror=disabled
%endif

%define tls_priority "@LIBVIRT,SYSTEM"


Summary: Library providing a simple virtualization API
Name: libvirt
Version: 7.6.0
Release: 2%{?dist}.14.3
License: LGPLv2+
URL: https://libvirt.org/
ExclusiveArch: x86_64

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: libvirt-%{version}.tar.xz
Source1: symlinks

Patch1: libvirt-RHEL-Fix-virConnectGetMaxVcpus-output.patch
Patch2: libvirt-RHEL-Enable-usage-of-x-blockdev-reopen.patch

# Vz patches
Patch10000: 10000-vz-compile-fixes.patch
Patch10001: 10001-vz-fixes-after-renaming-Parallels-to-Virtuozzo-in-s.patch
Patch10002: 10002-iohelper-truncate-large-chunks-on-write-PSBM-70840.patch
Patch10003: 10003-Added-new-flag-VIR_DOMAIN_CREATE_USER.patch
Patch10004: 10004-conf-tune-connection-parameters-for-Virtuozzo-PSBM-.patch
Patch10005: 10005-Set-LimitCORE-infinity-in-libvirtd.service.patch
Patch10006: 10006-conf-add-format-attribute-to-domain-os-nvram-elemen.patch
Patch10007: 10007-qemu-don-t-pause-vm-when-creating-internal-snapshot.patch
Patch10008: 10008-vz-use-etc-machine-id-as-host-uuid.patch
Patch10009: 10009-qemu-log-log-monitor-events-by-default.patch
Patch10010: 10010-relax-network-adapter-config-checking-bug-PSBM-5459.patch
Patch10011: 10011-qemu-v2-fix-reboot-scenario-bugs-PSBM-41956-PSBM-54.patch
Patch10012: 10012-vz-set-virtio-as-default-network-model.patch
Patch10013: 10013-qemu-fix-crash-on-getting-block-stats-for-empty-cdr.patch
Patch10014: 10014-vz-rework-the-way-we-get-perfomance-counters.patch
Patch10015: 10015-vz-use-cached-statistics-for-a-predefined-period.patch
Patch10016: 10016-vz-don-t-subscribe-to-perfomance-counters.patch
Patch10017: 10017-vz-cleanup-delete-unused-constant-definition.patch
Patch10018: 10018-vz-don-t-create-driver-object-during-daemon-initial.patch
Patch10019: 10019-conf-qemu-add-hv-scsi-model-to-scsi-controllers.patch
Patch10020: 10020-vz-add-domain-name-info-in-error-message.patch
Patch10021: 10021-qemu-simplify-graphics-port-releasing.patch
Patch10022: 10022-upgrade-support-local-p2p-migration.patch
Patch10023: 10023-object-add-shared-lock-option-to-lockable.patch
Patch10024: 10024-upgrade-initial-implementation.patch
Patch10025: 10025-upgrade-don-t-show-events-from-not-face-process.patch
Patch10026: 10026-upgrade-start-target-domain-with-source-id.patch
Patch10027: 10027-cgroup-use-id-generation-for-machine-cgroup-name-if.patch
Patch10028: 10028-upgrade-fix-id-clashes-for-domain-private-paths-etc.patch
Patch10029: 10029-conf-accept-path-in-virDomainSaveXML.patch
Patch10030: 10030-upgrade-store-generation-in-status-file.patch
Patch10031: 10031-dom-list-refactor-reuse-code-in-find-functions.patch
Patch10032: 10032-upgrade-return-face-domain-from-domlist.patch
Patch10033: 10033-migration-support-release-ram.patch
Patch10034: 10034-migration-add-postcopy-start-to-start-postcopy-imme.patch
Patch10035: 10035-upgrade-virtlogd-handle-output-for-one-path-from-2-.patch
Patch10036: 10036-upgrade-pass-live-config-to-target.patch
Patch10037: 10037-upgrade-don-t-generate-seclabel-again-on-upgrade.patch
Patch10038: 10038-upgrade-handle-auto-generated-char-dev-unix-paths.patch
Patch10039: 10039-upgrade-vnc-do-not-regenerate-graphics-for-target-p.patch
Patch10040: 10040-upgrade-vnc-factor-out-building-vnc-opts.patch
Patch10041: 10041-upgrade-vnc-make-vnc-upgrade-possible.patch
Patch10042: 10042-upgrade-vnc-keep-vnc-state-across-upgrade.patch
Patch10043: 10043-qemu-add-local_migration-param-to-qemu.conf.patch
Patch10044: 10044-upgrade-tap-use-multiqueue-to-make-upgrade-possible.patch
Patch10045: 10045-upgrade-network-iface-keep-actual-net.patch
Patch10046: 10046-upgrade-snapshots-support-snapshots.patch
Patch10047: 10047-upgrade-don-t-assign-dev-aliases-on-upgrade.patch
Patch10048: 10048-qemu-drop-acquiring-job-condition-on-removing-vm-fr.patch
Patch10049: 10049-qemu-fix-one-more-race-on-undefining-and-create.patch
Patch10050: 10050-upgrade-restart-pending-jobs-after-upgrade.patch
Patch10051: 10051-upgrade-fix-domain-lookup-in-old-face-removing-phas.patch
Patch10052: 10052-upgrade-make-correct-reconnection-of-upgrade.patch
Patch10053: 10053-upgrade-set-used-ports-only-for-face.patch
Patch10054: 10054-upgrade-support-for-server-backends-for-serial-char.patch
Patch10055: 10055-qemu.conf-set-upper-limit-for-vnc-spice-ports-to-69.patch
Patch10056: 10056-upgrade-don-t-reject-upgrade-if-hostname-is-localho.patch
Patch10057: 10057-qemu-wait-indefinetly-when-acquiring-job-condition-.patch
Patch10058: 10058-upgrade-close-agent-channel-befor-postcopy-with-rel.patch
Patch10059: 10059-upgrade-use-unique-name-for-pidfiles-across-upgrade.patch
Patch10060: 10060-qemu-remove-time-limit-on-waiting-qemu-disappearenc.patch
Patch10061: 10061-qemu-add-vmbus-bridge-device-if-hv-scsi-present.patch
Patch10062: 10062-qemu-agent-stop-io-loop-effectively-on-eof-or-error.patch
Patch10063: 10063-upgrade-fix-crash-if-vm-newdef-is-empty.patch
Patch10064: 10064-libvirtd-tune-OOMScoreAdjust.patch
Patch10065: 10065-qemu-revert-fb2cd32c.patch
Patch10066: 10066-qemu-monitor-check-monitor-not-closed-on-send.patch
Patch10067: 10067-vz-remove-domain-uuid-check-on-migration-PSBM-43767.patch
Patch10068: 10068-qemu-support-hv-net-interface-models.patch
Patch10069: 10069-nwfilter-fix-deadlock-on-firewalld-restart-reload.patch
Patch10070: 10070-vz-allow-to-start-vz-driver-without-host-cache-info.patch
Patch10071: 10071-qemu-snapshot-revert-upstream-9e2465834-PSBM-76749.patch
Patch10072: 10072-api-qemu-add-block-pull-compress-option-PSBM-73618.patch
Patch10073: 10073-qemu-include-nvram-into-offline-snapshots.patch
Patch10074: 10074-qemu-fail-making-internal-snapshots-with-non-qcow2-.patch
Patch10075: 10075-util-virFDStreamConnectUNIX-add-missing-error-repor.patch
Patch10076: 10076-util-add-30s-connection-timeout-to-virFDStreamConne.patch
Patch10077: 10077-qemu-use-job-to-make-domain-responsive-on-qemuDomai.patch
Patch10078: 10078-qemu-wait-qemu-death-indefinetely-on-domain-stop-PS.patch
Patch10079: 10079-pull-api-add-API-for-pull-external-backups.patch
Patch10080: 10080-pull-api-add-driver-based-implementation.patch
Patch10081: 10081-pull-remote-add-pull-backup-API-implementation.patch
Patch10082: 10082-pull-qemu-monitor-add-commands-for-backup.patch
Patch10083: 10083-pull-conf-add-block-snapshot-format-parse.patch
Patch10084: 10084-pull-virsh-add-block-snapshot-create-delete.patch
Patch10085: 10085-qemu-store-guest-visible-disk-size-from-qemu-monito.patch
Patch10086: 10086-pull-conf-add-block-snaphots-to-status-file.patch
Patch10087: 10087-pull-qemu-block-snapshots-basic-implementation.patch
Patch10088: 10088-pull-qemu-support-disks-quiesce.patch
Patch10089: 10089-pull-qemu-add-block-snapshots-listing.patch
Patch10090: 10090-pull-qemu-support-block-snapshot-dumpxml.patch
Patch10091: 10091-pull-qemu-monitor-add-cmd-to-delete-nbd-export.patch
Patch10092: 10092-pull-conf-add-export-conf-def-parsing.patch
Patch10093: 10093-pull-qemu-implement-export-start-stop.patch
Patch10094: 10094-pull-qemu-don-t-delete-snapshot-while-disks-are-exp.patch
Patch10095: 10095-util-hash-remove-const-from-value-in-kv-pair-type.patch
Patch10096: 10096-pull-add-autodelete-option-for-creating-block-snaps.patch
Patch10097: 10097-pull-stop-exporting-snapshot-on-snapshot-autodelete.patch
Patch10098: 10098-pull-qemu-monitor-add-bitmap-commands.patch
Patch10099: 10099-pull-pull-add-dirty-bitmap-on-creating-snapshot.patch
Patch10100: 10100-pull-add-command-to-remove-checkpoint.patch
Patch10101: 10101-pull-qemu-remove-checkpoint-on-autodelete.patch
Patch10102: 10102-pull-qemu-load-bitmaps-on-domain-start.patch
Patch10103: 10103-pull-qemu-monitor-add-command-to-export-bitmap.patch
Patch10104: 10104-pull-export-bitmap.patch
Patch10105: 10105-pull-migrate-checkpoints.patch
Patch10106: 10106-pull-qemu-validate-snapshot-name.patch
Patch10107: 10107-pull-qemu-add-exportable-paused-start.patch
Patch10108: 10108-pull-add-TLS-to-block-export.patch
Patch10109: 10109-pull-add-relaxng.patch
Patch10110: 10110-pull-add-autoport-on-export.patch
Patch10111: 10111-qemu-add-unmap-stats-to-all-domain-stats.patch
Patch10112: 10112-api-qemu-add-latency-histogram.patch
Patch10113: 10113-hubapi-remote-implement-listing-domains.patch
Patch10114: 10114-hubapi-remote-support-domain-API-calls.patch
Patch10115: 10115-hubapi-remote-support-domain-lookup-functions.patch
Patch10116: 10116-hubapi-remote-support-create-define-xml-API.patch
Patch10117: 10117-hubapi-remote-support-domain-events.patch
Patch10118: 10118-hubapi-remote-support-virConnectGetCapabilities.patch
Patch10119: 10119-hubapi-remote-return-vz-connection-type-if-vz-is-in.patch
Patch10120: 10120-hubapi-remote-return-vz-connection-type-if-vzct-is-.patch
Patch10121: 10121-hubapi-find-appropriate-connection-for-domain-xml-V.patch
Patch10122: 10122-vz-add-option-to-resize-filesystems-thur-virDomainB.patch
Patch10123: 10123-vz-support-virDomainGetBlockInfo-in-driver.patch
Patch10124: 10124-api-qemu-introduce-hv-vss-freeze-thaw.patch
Patch10125: 10125-pull-disable-risky-cases-with-RW-NBD-exports.patch
Patch10126: 10126-qemu-fix-attach-detach-char-devices-to-use-guest-de.patch
Patch10127: 10127-conf-remove-none-console-target-type-check-from-vir.patch
Patch10128: 10128-conf-remove-none-console-target-type-check-from-vir.patch
Patch10129: 10129-conf-remove-none-console-target-type-check-from-vir.patch
Patch10130: 10130-qemu-update-compat-console-on-attach-first-serial-d.patch
Patch10131: 10131-qemu-support-updating-backend-of-serial-device.patch
Patch10132: 10132-pull-qemu-add-option-to-export-last-checkpoint.patch
Patch10133: 10133-portallocator-print-warn-on-releasing-not-used-port.patch
Patch10134: 10134-netlink-remove-watch-before-closing-fd.patch
Patch10135: 10135-qemu-monitor-set-error-flag-even-in-OOM-conditions.patch
Patch10136: 10136-utils-export-virCopyError.patch
Patch10137: 10137-qemu-fix-domain-object-wait-to-handle-monitor-error.patch
Patch10138: 10138-qemu-fix-races-in-beingDestroyed-usage.patch
Patch10139: 10139-lib-provide-error-message-in-new-blockjob-event.patch
Patch10140: 10140-qemu-agent-incapsulate-vm-reference-management.patch
Patch10141: 10141-qemu-agent-remove-unconvinient-destroy-callback.patch
Patch10142: 10142-qemu-agent-factor-out-code-to-open-channel.patch
Patch10143: 10143-qemu-agent-remove-useless-signalling.patch
Patch10144: 10144-qemu-agent-do-not-take-moninor-ref-in-IO-callback.patch
Patch10145: 10145-qemu-agent-remove-qemuAgentNotifyCloseLocked.patch
Patch10146: 10146-qemu-agent-don-t-retry-first-sync-message-if-monito.patch
Patch10147: 10147-qemu-agent-better-error-message-for-disconnected-ag.patch
Patch10148: 10148-qemu-agent-give-same-message-on-monitor-errors.patch
Patch10149: 10149-qemu-agent-move-monitor-error-check-to-better-place.patch
Patch10150: 10150-qemu-domain-add-name-arg-to-qemuFindAgentConfig.patch
Patch10151: 10151-qemu-agent-prepare-serial-event-handler-for-aux-cha.patch
Patch10152: 10152-rpc-support-multiple-streams-on-client-side.patch
Patch10153: 10153-rpc-fix-to-support-multiple-streams.patch
Patch10154: 10154-rpc-close-stream-on-receive-errors.patch
Patch10155: 10155-rpc-pass-original-stream-recv-send-error.patch
Patch10156: 10156-qemu-add-exec-with-true-streams.patch
Patch10157: 10157-tools-stop-event-loop-before-closing-connection.patch
Patch10158: 10158-virsh-don-t-print-n-footer-for-x-exec.patch
Patch10159: 10159-misc-remove-some-invalid-G_GNUC_WARN_UNUSED_RESULT.patch
Patch10160: 10160-nwfilter-use-vfork-to-fasten-spawn-of-ip-eb-tables-.patch
Patch10161: 10161-pci-more-verbose-error-in-virPCIGetDeviceAddressFro.patch
Patch10162: 10162-daemon-purge-logs-for-domains-removed-more-than-mon.patch
Patch10163: 10163-remote-fix-SIGSEGV-on-closing-client-connection.patch
Patch10164: 10164-pull-don-t-destroy-vm-if-it-has-block-snapshots-or-.patch
Patch10165: 10165-qemu-destroy-domain-on-monitor-EOF-anyway.patch
Patch10166: 10166-pull-log-merge-rename-bitmap-operations.patch
Patch10167: 10167-api-qemu-add-move-nvram-API.patch
Patch10168: 10168-qemu-add-option-to-update-disk-copy_on_read-live-VS.patch
Patch10169: 10169-qemu-add-qcow2-cache-size-policy.patch
Patch10170: 10170-tools-move-virshGetEscapeChar-to-utils.patch
Patch10171: 10171-virsh-support-in-err-out-as-regular-files.patch
Patch10172: 10172-qemu-support-interactive-exec-PSBM-91739.patch
Patch10173: 10173-qemu-remove-sanity-check-in-qemuMonitorJSONDiskName.patch
Patch10174: 10174-exec-provide-tty-params-on-exec-when-possible.patch
Patch10175: 10175-rpc-allow-comments-in-prototol-description.patch
Patch10176: 10176-remote-leave-stub-comment-for-16-virDomainGetOSInfo.patch
Patch10177: 10177-libvirt-add-new-virDomainCommandXSetParams-API.patch
Patch10178: 10178-exec-handle-client-window-size-change-when-interact.patch
Patch10179: 10179-qemu-add-hci-value-128MiB-to-qcow2-disk-cache-polic.patch
Patch10180: 10180-upgrade-handle-firewall-rules-PSBM-90137.patch
Patch10181: 10181-qemu-caps-invalidate-kvm-capable-qemu-binaries-on-e.patch
Patch10182: 10182-cgroup-blacklist-criu-temporary-mounts-PSBM-90471.patch
Patch10183: 10183-qemu-imply-qcow2-format-for-backing-store-if-not-se.patch
Patch10184: 10184-rpc-client-fix-race-on-stream-error-and-stream-crea.patch
Patch10185: 10185-exec-virsh-support-redirection-to-special-chardevs-.patch
Patch10186: 10186-exec-restore-std-streams-flags-on-become-foreground.patch
Patch10187: 10187-rpc-client-stream-notify-streams-of-closing-connect.patch
Patch10188: 10188-Revert-log-actually-do-substring-matches-with-fnmat.patch
Patch10189: 10189-pull-clean-autodelete-snapshots-on-daemon-restart.patch
Patch10190: 10190-qemu-agent-add-code-2-when-guest-exec-pid-not-found.patch
Patch10191: 10191-qemu-don-t-wait-job-in-cleanup-thread.patch
Patch10192: 10192-exec-kill-orphans-on-client-disconnect-PSBM-91329-V.patch
Patch10193: 10193-exec-kill-orphans-on-migration-destination-PSBM-913.patch
Patch10194: 10194-qemu-seccomp-don-t-turn-it-on-by-default-PSBM-93004.patch
Patch10195: 10195-qemu-ignore-disabled-arch-facilities-in-configs-PSB.patch
Patch10196: 10196-qemu-support-explicit-disk-backing-in-input-VSTOR-2.patch
Patch10197: 10197-logging-remove-watch-before-closing-fd-in-virLogHan.patch
Patch10198: 10198-qemu-don-t-log-error-for-disk-sources-not-supportin.patch
Patch10199: 10199-qemu-don-t-log-error-when-monitor-EOF-is-expected-P.patch
Patch10200: 10200-qemu-agent-don-t-log-error-when-monitor-EOF-is-expe.patch
Patch10201: 10201-qemu-agent-aux-don-t-log-error-when-monitor-EOF-is-.patch
Patch10202: 10202-qemu-qemuBlockDiskDetectNodes-get-name-if-one-is-kn.patch
Patch10203: 10203-backup-copy-bitmaps-to-top-image-on-snapshot.patch
Patch10204: 10204-virDomainObjListAddObjLocked-Don-t-expect-vm-def-to.patch
Patch10205: 10205-virDomainObjListAddLocked-Set-vm-def-only-in-succes.patch
Patch10206: 10206-virDomainObjListAdd-Leave-def-assigning-as-an-exerc.patch
Patch10207: 10207-virDomainObjListAdd-Remove-unused-flag.patch
Patch10208: 10208-qemu-Grab-modify-job-for-changing-domain-XML.patch
Patch10209: 10209-qemu_domain-Allow-qemuDomainObjListAdd-to-keep-job-.patch
Patch10210: 10210-qemu-release-job-on-cleanup-path.patch
Patch10211: 10211-qemu-snapshot-revert-reuse-common-cleanup-code.patch
Patch10212: 10212-qemu-support-snapshots-done-with-Vz-downstream-patc.patch
Patch10213: 10213-schema-snapshot-add-persistent-domain-config.patch
Patch10214: 10214-docs-add-persistent-config-to-snapshot-xml-descript.patch
Patch10215: 10215-conf-snapshot-check-domain-name-on-redefine.patch
Patch10216: 10216-conf-snapshot-support-persistent-config-on-redefine.patch
Patch10217: 10217-qemu-add-option-to-close-cdrom-tray-PSBM-95870.patch
Patch10218: 10218-conf-remove-features-unknown-to-qemu-related-to-PSB.patch
Patch10219: 10219-agent-increase-default-timeout-from-5s-to-30s-PSBM-.patch
Patch10220: 10220-qemu-introduce-qemuDomainChrSerialTargetModel.patch
Patch10221: 10221-conf-add-debugcon-chardev-guest-interface.patch
Patch10222: 10222-qemu-make-irq-optional-when-formatting-the-ISA-addr.patch
Patch10223: 10223-qemu-implement-debugcon-chardev.patch
Patch10224: 10224-qemu-autoadd-iobase-to-debugcon-chardev.patch
Patch10225: 10225-api-qemu-add-pause-resume-for-blockjobs.patch
Patch10226: 10226-qemu-agent-log-total-tx-rx-for-streams.patch
Patch10227: 10227-debug-print-thr-a-a-bt-in-log-when-taking-some-mute.patch
Patch10228: 10228-qemu-monitor-throttle-logging-BLOCK_IO_ERROR-events.patch
Patch10229: 10229-qemu-ignore-delayed-EOF-events-from-previous-VM-inc.patch
Patch10230: 10230-qemu-don-t-fail-pausing-block-job-if-it-is-missing-.patch
Patch10231: 10231-qemu-migration-implement-shared-workaround-VSTOR-11.patch
Patch10232: 10232-conf-handle-empty-string-in-interface-target-name-P.patch
Patch10233: 10233-conf-add-replug-option-for-usb-hostdev.patch
Patch10234: 10234-qemu-track-hostdev-delete-intention.patch
Patch10235: 10235-qemu-support-host-usb-device-unplug.patch
Patch10236: 10236-qemu-support-usb-hostdev-plugging-back.patch
Patch10237: 10237-qemu-handle-host-usb-device-add-del-udev-events.patch
Patch10238: 10238-qemu-handle-libvirtd-restart-after-host-usb-device-.patch
Patch10239: 10239-qemu-handle-race-on-device-deletion-and-usb-host-de.patch
Patch10240: 10240-qemu-hotplug-update-device-list-on-device-deleted-e.patch
Patch10241: 10241-qemu-handle-host-usb-device-plug-unplug-when-libvir.patch
Patch10242: 10242-qemu-don-t-mess-with-non-mandatory-hostdevs-on-reat.patch
Patch10243: 10243-qemu-handle-detaching-of-unplugged-hostdev.patch
Patch10244: 10244-conf-parse-hostdev-missing-flag.patch
Patch10245: 10245-backup-don-t-keep-bitmaps-in-base-image-on-snapshot.patch
Patch10246: 10246-backup-copy-bitmaps-down-on-active-block-commit-VST.patch
Patch10247: 10247-qemu-support-new-qemu-without-nbd-server-add-bitmap.patch
Patch10248: 10248-fix-for-virDomainObjListAdd-Leave-def-assigning-as-.patch
Patch10249: 10249-qemu-handle-storage-virtlogd-hanging-VSTOR-27947.patch
Patch10250: 10250-qemu-add-option-to-process-offloaded-legacy-blockjo.patch
Patch10251: 10251-qemu-reconnect-precreate-legacy-blockjobs.patch
Patch10252: 10252-qemu-remove-extra-block-job-finalize-on-reconnect.patch
Patch10253: 10253-qemu-remove-stale-cleanup-in-qemuProcessRefreshLega.patch
Patch10254: 10254-qemu-add-note-for-outdated-legacy-block-job-events.patch
Patch10255: 10255-qemu-use-autoptr-in-qemuProcessRefreshLegacyBlockjo.patch
Patch10256: 10256-qemu-refresh-backing-chain-after-block-job-reconnec.patch
Patch10257: 10257-qemu-move-code-that-depends-on-backing-chain-approp.patch
Patch10258: 10258-qemu-fix-race-on-legacy-block-completion-and-querin.patch
Patch10259: 10259-qemu-sync-backing-chain-update-and-completed-blockj.patch
Patch10260: 10260-qemu-support-preserve-option-for-on_poweroff.patch
Patch10261: 10261-qemu-add-reconnect-params-for-nbd-network-disks-VST.patch
Patch10262: 10262-qemu-kill-partially-started-domain-immediately-on-r.patch
Patch10263: 10263-qemu-disable-snapshot-explicitly-when-block-snapsho.patch
Patch10264: 10264-asan-workaround-sanitizer-issues-with-clone-2.patch
Patch10265: 10265-asan-configure-to-coredump-on-signals.patch
Patch10266: 10266-hubapi-workaround-virURIFormat-degradation-in-vz8.patch
Patch10267: 10267-qemu-adopt-nodename-detection-to-backup-filter-node.patch
Patch10268: 10268-qemu-turn-on-keep-alive-for-nbd-disk-migration-PSBM.patch
Patch10269: 10269-conf-add-more-options-to-save-config-filename.patch
Patch10270: 10270-conf-allow-NULL-callback-in-virDomainObjListRename.patch
Patch10271: 10271-conf-support-extra-id-in-domain-list.patch
Patch10272: 10272-vzct-2-add-basic-structure-and-listing.patch
Patch10273: 10273-virsystemd-workaround-race-on-systemd-machined-idle.patch
Patch10274: 10274-rpc-add-timeout-on-connection-VSTOR-32643.patch
Patch10275: 10275-conf-support-light-vcpus-and-unlimitied-number.patch
Patch10276: 10276-vzct-2-support-dumpxml.patch
Patch10277: 10277-vzct-2-implement-define.patch
Patch10278: 10278-vzct-2-implement-start-stop.patch
Patch10279: 10279-vzct-2-support-vnc-PSBM-104068.patch
Patch10280: 10280-vzct-2-support-cloud-init-cdrom-PSBM-104067.patch
Patch10281: 10281-vzct-2-support-iolimits-PSBM-104069.patch
Patch10282: 10282-vzct-2-add-misc-API.patch
Patch10283: 10283-vzct-2-support-stats-API-PSBM-104070.patch
Patch10284: 10284-qemu-use-explicit-backing-mode-only-if-there-is-nbd.patch
Patch10285: 10285-qemu-optimize-qemuOpenFileAs-for-reads-VSTOR-34701.patch
Patch10286: 10286-Add-qemu-hook-suitable-to-handle-device-hotplug-hot.patch
Patch10287: 10287-util-add-virFileRead-function.patch
Patch10288: 10288-conf-moment-remember-if-name-is-autogenerated.patch
Patch10289: 10289-vzct-2-support-snapshots.patch
Patch10290: 10290-xml-add-venet0-network-interface-type.patch
Patch10291: 10291-vzct-2-support-venet0-network-interface-PSBM-105548.patch
Patch10292: 10292-qemu-ignore-allow_disk_format_probing-PSBM-105558.patch
Patch10293: 10293-upgrade-don-t-mess-with-security-labels-PSBM-105674.patch
Patch10294: 10294-qemu-pass-rememberOwner-during-update-PSBM-105674.patch
Patch10295: 10295-qemu-auto-load-vhost-vsock-module-PSBM-106171.patch
Patch10296: 10296-virsh-handle-snapshots-with-domain-state-unknown.patch
Patch10297: 10297-util-add-means-to-detect-vstorage-filesystem.patch
Patch10298: 10298-security-exclude-vstorage-from-labelling-PSBM-10598.patch
Patch10299: 10299-vzct-2-don-t-try-virDomainLookupByID.patch
Patch10300: 10300-qemu-caps-use-more-precise-condition-when-to-use-CA.patch
Patch10301: 10301-doc-adopt-README.md-for-Virtuozzo.patch
Patch10302: 10302-Add-new-type-of-storage-pool-for-Windows-Storage-Sp.patch
Patch10303: 10303-virsh-don-t-shout-if-virDomainGetJobInfo-is-not-sup.patch
Patch10304: 10304-vzct-2-save-disks-uuid-in-config-status-files.patch
Patch10305: 10305-vzct-2-intoduce-migration.patch
Patch10306: 10306-conf-add-auto-mininal-memory-guarantee-mode.patch
Patch10307: 10307-vzct-2-support-memory-guarantees-PSBM-106482.patch
Patch10308: 10308-vzct-2-mark-supported-xml-parts-in-domain-snapshot-.patch
Patch10309: 10309-qemu-add-vcmmd-support-PSBM-106483.patch
Patch10310: 10310-qemu-agent-disable-blocking-calls-to-agent-PSBM-107.patch
Patch10311: 10311-vzct-2-add-jobs-support-for-everything-except-migra.patch
Patch10312: 10312-vzct-2-support-jobs-during-migration-PSBM-107444.patch
Patch10313: 10313-vzct-2-drop-job-on-client-disconnection-during-migr.patch
Patch10314: 10314-Changes-for-support-DNS-configuration-PSBM-106778.patch
Patch10315: 10315-vzct-2-add-lifecycle-events-PSBM-107730.patch
Patch10316: 10316-vzct-2-support-getting-stats-for-migration-PSBM-107.patch
Patch10317: 10317-vzct-2-support-aborting-domain-job-API-PSBM-107446.patch
Patch10318: 10318-vstorage-migration-execute-src-migration-cleanup-in.patch
Patch10319: 10319-qemu-monitor-bring-add-remove-fd-commands-back.patch
Patch10320: 10320-qemu-don-t-leave-descriptors-in-fdsets-after-proces.patch
Patch10321: 10321-qemu-support-file-chardev-append-option-on-hotplug-.patch
Patch10322: 10322-qemu-support-logfile-option-on-chardev-hotplug-chan.patch
Patch10323: 10323-qemu-migration-add-cookie-parts-for-vstorage-charde.patch
Patch10324: 10324-logging-close-backing-file-on-eof-on-drain.patch
Patch10325: 10325-qemu-monitor-add-option-to-override-backend-in-qemu.patch
Patch10326: 10326-qemu-migration-support-changing-chardev-backend-wit.patch
Patch10327: 10327-logging-handle-race-on-drain-and-closing-in-event-l.patch
Patch10328: 10328-logging-allow-NULL-to-inode-and-offset-out-args-on-.patch
Patch10329: 10329-qemu-migration-detect-shared-vstorage-chardevs.patch
Patch10330: 10330-vstorage-support-migrating-with-chardevs-on-vstorag.patch
Patch10331: 10331-qemu-add-vstorage-chardev-tmpfile-names-to-status-f.patch
Patch10332: 10332-qemu-sync-chardevs-unplugged-status-on-reconnect.patch
Patch10333: 10333-qemu-cleanup-up-vstorage-chardevs-after-libvirtd-cr.patch
Patch10334: 10334-qemu-drain-file-chardevs-on-domain-process-stop.patch
Patch10335: 10335-vstorage-migration-introduce-virDomainMigrateVstora.patch
Patch10336: 10336-vstorage-migration-add-vstorage-snapshot-commit-pha.patch
Patch10337: 10337-vstorage-migration-add-vstorage-disks-info-to-cooki.patch
Patch10338: 10338-qemu-add-vstorage-snapshot-utility-functions.patch
Patch10339: 10339-vstorage-migration-add-vstorage-nvram-info-to-cooki.patch
Patch10340: 10340-qemu-add-nvram-block-job-support.patch
Patch10341: 10341-vstorage-migration-add-vstorage-snapshot-commit.patch
Patch10342: 10342-qemu-introduce-qemuDomainCreateImage.patch
Patch10343: 10343-vstorage-migration-main-patch-PSBM-106202.patch
Patch10344: 10344-vstorage-migration-support-p2p.patch
Patch10345: 10345-vstorage-load-bitmaps-from-base-image-for-tmp-snaps.patch
Patch10346: 10346-vstorage-migration-track-valid-temporary-snapshot.patch
Patch10347: 10347-vstorage-migration-resolve-valid-tmp-snapshot-on-do.patch
Patch10348: 10348-vstorage-migration-disable-API-that-can-clash-with-.patch
Patch10349: 10349-vstorage-migration-don-t-parse-tmp-snapshot-commit-.patch
Patch10350: 10350-vstorage-migration-keep-snapshot-info-in-status.patch
Patch10351: 10351-vstorage-migration-add-dst-cleanup-after-disconnect.patch
Patch10352: 10352-vstorage-migration-determine-valid-snapshot-on-cras.patch
Patch10353: 10353-qemu-migration-fix-missing-owner-on-disconnection-c.patch
Patch10354: 10354-qemu-cleanup-tmp-snapshot-PSBM-106875.patch
Patch10355: 10355-qemu-support-nvram-block-job-on-reconnect.patch
Patch10356: 10356-vstorage-migration-handle-ready-state-on-reconnect-.patch
Patch10357: 10357-qemu-add-filename-to-qemuMonitorGetBlockInfo.patch
Patch10358: 10358-vstorage-migration-handle-completed-tmp-snapshot-co.patch
Patch10359: 10359-nwfilter-add-vz-specific-filters-PSBM-121477.patch
Patch10360: 10360-vstorage-migration-keep-nvram-tmp-snapshot-in-statu.patch
Patch10361: 10361-vstorage-migration-adopt-qemuDomainGetStatsOneBlock.patch
Patch10362: 10362-vstorage-migration-fix-active-block-stats-with-tmp-.patch
Patch10363: 10363-vstorage-migration-fix-inactive-block-stats-with-tm.patch
Patch10364: 10364-vstorage-migration-handle-short-time-EBUSY-on-commi.patch
Patch10365: 10365-api-add-stub-for-virDomainBlockCheckpointXSwitch.patch
Patch10366: 10366-api-add-VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO.patch
Patch10367: 10367-tools-support-memtune-min-guarantee-auto-vz.patch
Patch10368: 10368-qemu-support-min_gurantee-in-virDomain-Set-Get-Memo.patch
Patch10369: 10369-Fix-for-possibility-to-use-inituser-without-initgro.patch
Patch10370: 10370-vzct-2-support-autostarting-domains-PSBM-121587.patch
Patch10371: 10371-qemu-turn-on-postcopy-to-migrate-bitmaps-PSBM-10017.patch
Patch10372: 10372-qemu-fix-guest-visible-disk-id-if-serial-is-long-VS.patch
Patch10373: 10373-qemu-fix-managed-pr-helper-tear-down-on-chaning-dev.patch
Patch10374: 10374-doc-document-virsh-commands-for-block-snaphots-expo.patch
Patch10375: 10375-vz-fix-after-Parallels-to-Virtuozzo-rename-PSBM-124.patch
Patch10376: 10376-virsh-fix-Vstorage-support-reporting.patch
Patch10377: 10377-exec-don-t-print-errors-to-stderr-PSBM-124629.patch
Patch10378: 10378-vzct-2-implement-exec-API-PSBM-106206.patch
Patch10379: 10379-virsh-don-t-call-virDomainGetGuestInfo-for-vzct-int.patch
Patch10380: 10380-daemon-switch-off-autoshutdown-VSTOR-40335.patch
Patch10381: 10381-api-fix-documentation-typo.patch
Patch10382: 10382-misc-add-bypass-cache-flag-for-block-snapshot-creat.patch
Patch10383: 10383-vzct-Support-setting-memory-for-active-CT-PSBM-1224.patch
Patch10384: 10384-vzct-Support-setting-cpu-num-for-active-CT-PSBM-122.patch
Patch10385: 10385-docs-document-backup-API-PSBM-124261.patch
Patch10386: 10386-vzct-Support-setting-memory-guarantee-for-active-CT.patch
Patch10387: 10387-vzct-Support-setting-IO-limits-for-active-CT-PSBM-1.patch
Patch10388: 10388-tools-treat-in-shutdown-etc-as-shutdown-finished-VS.patch
Patch10389: 10389-qemu-don-t-error-if-cannot-find-disk-by-alias-PSBM-.patch
Patch10390: 10390-qemu-vcmmd-support-for-setting-balloon-PSBM-123145.patch
Patch10391: 10391-qemu-better-cluster-size-for-tmp-deltas-on-vstorage.patch
Patch10392: 10392-util-add-hanging-process-debugging-PSBM-126062.patch
Patch10393: 10393-vzct-Support-disk-resize-for-active-CT-PSBM-122525.patch
Patch10394: 10394-qemu-detect-block-node-names-after-attaching-a-disk.patch
Patch10395: 10395-qemu-api-support-min_guarantee-as-fraction-of-ballo.patch
Patch10396: 10396-security-don-t-restore-labels-for-readonly-and-shar.patch
Patch10397: 10397-qemu-fix-noisy-error-for-domain-with-image-on-reado.patch
Patch10398: 10398-misc-add-blockjob-type-for-block-snapshot-job-PSBM-.patch
Patch10399: 10399-qemu-monitor-add-qemuMonitorBlockDirtyBitmapRemoveB.patch
Patch10400: 10400-util-add-virTimeBackOffWaitUnlocked.patch
Patch10401: 10401-backup-qemu-retry-bitmap-deletion-while-it-is-used-.patch
Patch10402: 10402-qemu-add-qemuMonitorJSONBlockdevDelBusy.patch
Patch10403: 10403-backup-qemu-retry-fleece-node-deletion-while-it-is-.patch
Patch10404: 10404-vstorage-migration-cleanup-precreated-src-tmp-delta.patch
Patch10405: 10405-upgrade-drain-chardev-s-pipes-PSBM-108071.patch
Patch10406: 10406-remote-remove-unused-daemonConfigLoadData.patch
Patch10407: 10407-util-move-virConf-definition-to-header.patch
Patch10408: 10408-util-make-conf-a-linked-list-of-configs.patch
Patch10409: 10409-util-add-virConfReadDir-to-read-dir-of-configs.patch
Patch10410: 10410-util-add-virConfCheckDuplicates-to-check-for-duplic.patch
Patch10411: 10411-remote-remove-filename-from-config-error-reporting.patch
Patch10412: 10412-remote-read-config-from-libvirtd.d-too-PSBM-127469.patch
Patch10413: 10413-qemu-read-config-from-qemu.d-too-PSBM-127469.patch
Patch10414: 10414-security-handle-chown-EACCES-on-readonly-cifs-mount.patch
Patch10415: 10415-vzct-add-ip-address-to-venet0-schema.patch
Patch10416: 10416-vzct-dump-ip-info-for-interfaces-PSBM-106470.patch
Patch10417: 10417-vzct-support-setting-net-interface-ips-on-define.patch
Patch10418: 10418-qemu-acquire-job-to-handle-agent-disconnection-PSBM.patch
Patch10419: 10419-nwfilter-don-t-add-symmetric-record-for-policy-rule.patch
Patch10420: 10420-qemu-notify-vcmmd-of-node-vcpu-pinning-PSBM-126679.patch
Patch10421: 10421-qemu-fix-restoring-label-if-usb-hostdev-is-detached.patch
Patch10422: 10422-qemu-handle-usb-hostdev-on-qemu-update-PSBM-97288.patch
Patch10423: 10423-qemu-handle-timeout-on-unplugging-device-on-qemu-up.patch
Patch10424: 10424-storage-open-code-storageBackendRedoPloopUpdate.patch
Patch10425: 10425-storage-fix-refreshing-ploop-volumes-PSBM-128810.patch
Patch10426: 10426-qemu-don-t-access-vm-without-lock.patch
Patch10427: 10427-qemu-request-flat-block-graph-output-when-possible.patch
Patch10428: 10428-TMP-temporary-fixes-to-unblock-most-of-cases.patch
Patch10429: 10429-vzct-support-cpumask-configuration-PSBM-107822.patch
Patch10430: 10430-vzct-support-numatune-nodeset-configuration-PSBM-10.patch
Patch10431: 10431-vstorage-pools-detect-vstorage.patch
Patch10432: 10432-vstorage-pools-use-external-metadata-on-pool-refres.patch
Patch10433: 10433-vstorage-pools-use-external-metadata-on-volume-refr.patch
Patch10434: 10434-vstorage-pools-save-metadata-on-creating-volume.patch
Patch10435: 10435-vstorage-pools-update-metadata-on-resizing-volume.patch
Patch10436: 10436-vstorage-volume-delete-metadata-on-deleting-volume.patch
Patch10437: 10437-vstorage-pools-cleanup-outdated-metadata.patch
Patch10438: 10438-qemu-capabilities-Add-capability-for-the-copy-mode-.patch
Patch10439: 10439-qemu-use-write-blocking-copy-mode-for-mirror-comman.patch
Patch10440: 10440-qemu-don-t-prohibit-of-cdrom-floppy-hot-attach-deta.patch
Patch10441: 10441-vzct-support-user-alias-for-devices-PSBM-130985.patch
Patch10442: 10442-MERGE-schema-snapshot-add-persistent-domain-config.patch
Patch10443: 10443-conf-remove-static-from-virDomainDefSetMetadata.patch
Patch10444: 10444-vzct-support-getting-setting-metadata-PSBM-131257.patch
Patch10445: 10445-qemu-add-hook-on-define-PSBM-130792.patch
Patch10446: 10446-qemu-add-virtuozzo-specific-hook-on-define.patch
Patch10447: 10447-qemu-vz-hook-set-machine-type-q35.patch
Patch10448: 10448-vzct-support-rename-PSBM-131350.patch
Patch10449: 10449-vstorage-migration-support-explicit-backing.patch
Patch10450: 10450-FIXUP-qemu-extract-private-exec-commands-PSBM-12974.patch
Patch10451: 10451-conf-add-vz-dhcp-parameter-to-xml-PSBM-129743.patch
Patch10452: 10452-qemu-support-setting-net-params-thru-prl_nettool-PS.patch
Patch10453: 10453-qemu-keep-netConfigApplied-in-status-file-PSBM-1297.patch
Patch10454: 10454-qemu-validate-that-route-is-default-gateway-PSBM-12.patch
Patch10455: 10455-qemu-vzhook-add-windows-tweaks-PSBM-130505-PSBM-130.patch
Patch10456: 10456-vstorage-migration-handle-tmp-snapshot-in-qemuProce.patch
Patch10457: 10457-qemu-support-changing-net-params-PSBM-129743.patch
Patch10458: 10458-vzct-2-support-volumes-in-define-undefine-stats-PSB.patch
Patch10459: 10459-vzct-2-support-volumes-on-start-stop-PSBM-128811.patch
Patch10460: 10460-vzct-2-store-disk-uuids-in-snapshot-metadata.patch
Patch10461: 10461-conf-virDomainSnapshotDefParse-allow-NULL-current.patch
Patch10462: 10462-vzct-2-support-volumes-for-snapshot-API-PSBM-128811.patch
Patch10463: 10463-vzct-2-add-destination-pool-info-to-migration-cooki.patch
Patch10464: 10464-vzct-2-migration-check-storage-pool-alignment-on-sr.patch
Patch10465: 10465-vzct-2-support-volumes-on-migration-PSBM-128811.patch
Patch10466: 10466-vzct-2-skip-actions-on-libvzctl-config-after-migrat.patch
Patch10467: 10467-Save-state-of-guest-tools-autoupdate-in-domain-meta.patch
Patch10468: 10468-qemu-fix-refreshing-of-restored-VM-PSBM-132173-upst.patch
Patch10469: 10469-qemu-Save-guest-tools-version-to-metadata-PSBM-1320.patch
Patch10470: 10470-qemu-add-support-for-live-changing-of-IP-settings-i.patch
Patch10471: 10471-vzct-use-guest-mac-address-as-configuration-paramet.patch
Patch10472: 10472-vzct-process-dhcp-dhcp6-CT-network-parameter.patch
Patch10473: 10473-vzct-2-support-VIR_DOMAIN_DESTROY_GRACEFUL-flag-PSB.patch
Patch10474: 10474-Fixed-x-block-snapshot-create-delete-functionality-.patch
Patch10475: 10475-Skip-LC_ALL-setting-for-define-hooks-PSBM-132202.patch
Patch10476: 10476-qemu-fix-events-when-destroy-on-reboot-PSBM-132238.patch
Patch10477: 10477-vircommand-fix-checking-mixing-daemon-and-string-ou.patch
Patch10478: 10478-vzct-support-virConnectGetHostname-PSBM-132591.patch
Patch10479: 10479-vzct-support-virNodeGetInfo-PSBM-132592.patch
Patch10480: 10480-vzct-support-virNodeGetCPUMap-PSBM-132594.patch
Patch10481: 10481-vzct-support-virConnectGetVersion-PSBM-132593.patch
Patch10482: 10482-vzct-support-misc-undefine-flags-PSBM-133506.patch
Patch10483: 10483-vzct-support-managed-save-related-API-PSBM-133505.patch
Patch10484: 10484-vzct-support-misc-cputune-settings-PSBM-133494.patch
Patch10485: 10485-remote-log-unix-socket-client-command-line-PSBM-133.patch
Patch10486: 10486-conf-remove-params-we-set-in-libvirtd.d-and-qemu.d-.patch
Patch10487: 10487-Add-description-of-vz-dns-element-PSBM-131363.patch
Patch10488: 10488-vzct-add-started-hook-PSBM-133731.patch
Patch10489: 10489-vzct-support-blkiotune-weight-settings-PSBM-133495.patch
Patch10490: 10490-qemu-load-bitmaps-on-disk-hotplug-VSTOR-45545.patch
Patch10491: 10491-Add-description-of-vz-dhcp-subelement-PSBM-131363.patch
Patch10492: 10492-nwfilter-introduce-method-to-utilize-filters-instan.patch
Patch10493: 10493-vzct-add-support-for-nwfilters-instantiated-after-c.patch
Patch10494: 10494-vzct-support-setting-default-gateway-PSBM-133497.patch
Patch10495: 10495-qemu-migration-check-for-blockjobs-in-qemu-explicit.patch
Patch10496: 10496-qemu-don-t-run-direct-monitor-commands-as-query.patch
Patch10497: 10497-vzct-support-for-vz-dns-section-PSBM-133621.patch
Patch10498: 10498-conf-make-virDomainDiskInsertPreAlloced-return-inse.patch
Patch10499: 10499-vzct-support-attaching-disks-PSBM-133912.patch
Patch10500: 10500-vzct-support-attaching-net-interface.patch
Patch10501: 10501-vzct-support-detaching-disks-PSBM-133912.patch
Patch10502: 10502-vzct-support-detachings-nets.patch
Patch10503: 10503-qemu-add-support-for-tune-guest-x-event-PSBM-134079.patch
Patch10504: 10504-vzct-support-virDomainUpdateDeviceFlags-PSBM-134064.patch
Patch10505: 10505-vzct-add-libosinfo-library-to-the-driver-build.patch
Patch10506: 10506-vzct-show-set-ostemplate-in-libosinfo-metadata-PSBM.patch
Patch10507: 10507-vzct-support-openvswitch-interface-id-PSBM-134313.patch
Patch10508: 10508-remote-handle-vcmmd-commands-in-a-priority-threads-.patch
Patch10509: 10509-qemu-disable-nbd-reconnect-on-migration-PSBM-134477.patch
Patch10510: 10510-qemu-allow-attaching-cdroms-with-empty-source-PSBM-.patch
Patch10511: 10511-vzct-support-vzctDomainSetUserPassword-PSBM-134928.patch
Patch10512: 10512-Adding-support-of-network-classes-to-libvirt-PSBM-1.patch
Patch10513: 10513-Adding-support-of-network-classes-to-vzct-PSBM-1346.patch
Patch10514: 10514-tools-fix-nsslinktest-build-in-vz9.patch
Patch10515: 10515-vzct-don-t-create-.libvirt-subdir-in-CT-private-if-.patch
Patch10516: 10516-qemu-support-for-network-traffic-shaping-by-nft-PSB.patch
Patch10517: 10517-conf-make-virDomainDefSaveXML-public.patch
Patch10518: 10518-conf-allow-VIR_DOMAIN_DEF_FORMAT_DISK_PRIVATE-for-v.patch
Patch10519: 10519-vzct-support-migrating-with-chaning-active-inactive.patch
Patch10520: 10520-vzct-check-changes-in-active-inactive-xml-are-suppo.patch
Patch10521: 10521-upgrade-notify-vcmmd-of-qemu-binary-update-PSBM-136.patch
Patch10522: 10522-vzct-update-UUID-if-it-is-changed-in-libvzctl-PSBM-.patch
Patch10523: 10523-qemu-implement-changing-VNC-port-on-a-running-VM-PS.patch
Patch10524: 10524-FIXUP-qemu-add-exec-with-true-streams.patch
Patch10525: 10525-FIXUP-api-qemu-add-latency-histogram.patch
Patch10526: 10526-DROP-qemu-support-file-chardev-append-option-on-hot.patch
Patch10527: 10527-FIXUP-qemu-migration-add-cookie-parts-for-vstorage-.patch
Patch10528: 10528-DROP-qemu-support-logfile-option-on-chardev-hotplug.patch
Patch10529: 10529-api-report-extraId-in-domain-xml-PSBM-136251.patch
Patch10530: 10530-FIXUP-handle-NULL-network-PSBM-137453.patch
Patch10531: 10531-FIXUP-nwfilter-add-vz-specific-filters-PSBM-137593.patch
Patch10532: 10532-qemu-temporary-don-t-show-default-audio-in-public-x.patch
Patch10533: 10533-FIXUP-vzct-check-changes-in-active-inactive-xml-are.patch
Patch10534: 10534-FIXUP-vzct-check-changes-in-active-inactive-xml-are.patch
Patch10535: 10535-FIXUP-vzct-2-drop-job-on-client-disconnection-durin.patch
Patch10536: 10536-FIXUP-fix-qemuMigrationChardevPlug-error-path.patch
Patch10537: 10537-FIXUP-fix-ABBA-potential-deadlock-on-access-to-migr.patch
Patch10538: 10538-FIXUP-use-migration-data-instead-of-simple-bool.patch
Patch10539: 10539-vzct-add-domain-state-info-to-the-cookie.patch
Patch10540: 10540-vzct-reserve-vnc-port-in-prepare-state-PSBM-107443.patch
Patch10541: 10541-REVERT-qemu-support-snapshots-done-with-Vz-downstre.patch
Patch10542: 10542-REVERT-schema-snapshot-add-persistent-domain-config.patch
Patch10543: 10543-FIXUP-mention-modern-element-name-for-inactive-doma.patch
Patch10544: 10544-FIXUP-simplify-stopping-all-block-exports-PSBM-1264.patch
Patch10545: 10545-FIXUP-fix-off-by-one-in-qemuGetVzScriptCommand-intr.patch
Patch10546: 10546-qemu-don-t-turn-on-evmcs-in-define-hook-for-AMD-PSB.patch
Patch10547: 10547-qemu-get-agent-right-after-availability-check-PSBM-.patch
Patch10548: 10548-FIXUP-vzct-2-intoduce-migration.patch

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-network = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_vzct}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires: python3-docutils
BuildRequires: gcc
BuildRequires: meson >= 0.54.0
BuildRequires: ninja-build
BuildRequires: git
BuildRequires: perl-interpreter
BuildRequires: python3
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: glib2-devel >= 2.56
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
BuildRequires: bash-completion >= 2.0
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel >= 1.5.0
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
BuildRequires: patch
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
BuildRequires: librados-devel
BuildRequires: librbd-devel
%endif
%if %{with_storage_gluster}
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif
%if %{with_netcf}
BuildRequires: netcf-devel >= 0.2.2
%endif
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.6.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

%if %{with_vz}
BuildRequires: libprlsdk-devel
%endif

%if %{with_vzct}
BuildRequires: ploop-devel
BuildRequires: libvzctl-devel >= 8.0.7
BuildRequires: libvcmmd-devel
BuildRequires: libvzevent-devel
BuildRequires: kernel-headers
BuildRequires: perl-XML-XPath
BuildRequires: libosinfo-devel
%endif

BuildRequires: rpcgen
BuildRequires: libtirpc-devel

# Needed for the firewalld_reload macro
%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

%if %{with_vcmmd}
BuildRequires: libvcmmd-devel
%endif

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# (client invokes 'nc' against the UNIX socket on the server)
Requires: /usr/bin/nc

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip
Requires: iproute
# for /sbin/tc
Requires: iproute-tc

Requires: polkit >= 0.112
%if %{with_dmidecode}
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): /usr/bin/systemctl
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext

# Ensure smooth upgrades
Obsoletes: libvirt-admin < 7.3.0
Provides: libvirt-admin = %{version}-%{release}
Obsoletes: libvirt-bash-completion < 7.3.0

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185
# For managing persistent mediated devices
Requires: mdevctl

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
%if %{with_netcf}
Requires: netcf-libs >= 0.2.2
%endif

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the host network interface APIs.

%if %{with_secret}
%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.
%endif

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%if %{with_storage_misc}
%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.
%endif


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%if %{with_storage_misc}
%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.
%endif


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
    %if 0%{?fedora}
Requires: glusterfs-client >= 2.0.1
    %endif
    %if (0%{?fedora} || 0%{?with_storage_gluster})
Requires: /usr/sbin/gluster
    %endif

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif

%if %{with_storage_vstorage}
%package daemon-driver-storage-vstorage
Summary: Storage driver plugin for Vstorage
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: vstorage-client

%description daemon-driver-storage-vstorage
The storage driver backend adding implementation of the storage APIs for
Vstorage volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
Requires: systemd-container
Requires: swtpm-tools
%if %{with_vcmmd}
Requires: libvcmmd
%endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: systemd-container

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif

%if %{with_vz}
%package daemon-driver-vz
Summary: Virtuozzo driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}

%description daemon-driver-vz
The vz driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Virtuozzo
%endif


%if %{with_vzct}
%package daemon-driver-vzct
Summary: Virtuozzo Containers driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvzctl >= 8.0.7
Requires: libosinfo
Requires: vzmigrate
Requires: prl-vzvncserver

%description daemon-driver-vzct
The libvirt hypervisor driver which provides access to Virtuozzo
containers
%endif


%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu-kvm

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%if %{with_vz}
%package daemon-vz
Summary: Server side daemon & driver required to run Virtuozzo guests
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vz = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vz
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo
%endif

%if %{with_vzct}
%package daemon-vzct
Summary: Server side daemon & driver required to run Virtuozzo containers
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vzct
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo containers
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
# Needed by virt-pki-validate script.
Requires: gnutls-utils

# Ensure smooth upgrades
Obsoletes: libvirt-bash-completion < 7.3.0

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi

%description libs
Shared libraries for accessing the libvirt daemon.

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -S git_am -N

# "make dist" replaces all symlinks with a copy of the linked files;
# we need to replace all of them with the original symlinks
echo "Restoring symlinks"
while read lnk target; do
    if [ -e $lnk ]; then
        rm -rf $lnk
        ln -s $target $lnk
    fi
done <%{_sourcedir}/symlinks || exit 1
git add .
git commit -q -a --allow-empty --author 'rpm-build <rpm-build>' -m symlinks


git config gc.auto 0

%autopatch

%build
%if 0%{?fedora} >= %{min_fedora} || 0%{?rhel} >= %{min_rhel}
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_qemu}
    %define arg_qemu -Ddriver_qemu=enabled
%else
    %define arg_qemu -Ddriver_qemu=disabled
%endif

%if %{with_openvz}
    %define arg_openvz -Ddriver_openvz=enabled
%else
    %define arg_openvz -Ddriver_openvz=disabled
%endif

%if %{with_lxc}
    %define arg_lxc -Ddriver_lxc=enabled
    %define arg_login_shell -Dlogin_shell=enabled
%else
    %define arg_lxc -Ddriver_lxc=disabled
    %define arg_login_shell -Dlogin_shell=disabled
%endif

%if %{with_vbox}
    %define arg_vbox -Ddriver_vbox=enabled
%else
    %define arg_vbox -Ddriver_vbox=disabled
%endif

%if %{with_libxl}
    %define arg_libxl -Ddriver_libxl=enabled
%else
    %define arg_libxl -Ddriver_libxl=disabled
%endif

%if %{with_esx}
    %define arg_esx -Ddriver_esx=enabled -Dcurl=enabled
%else
    %define arg_esx -Ddriver_esx=disabled -Dcurl=disabled
%endif

%if %{with_hyperv}
    %define arg_hyperv -Ddriver_hyperv=enabled -Dopenwsman=enabled
%else
    %define arg_hyperv -Ddriver_hyperv=disabled -Dopenwsman=disabled
%endif

%if %{with_vmware}
    %define arg_vmware -Ddriver_vmware=enabled
%else
    %define arg_vmware -Ddriver_vmware=disabled
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd -Dstorage_rbd=enabled
%else
    %define arg_storage_rbd -Dstorage_rbd=disabled
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog -Dstorage_sheepdog=enabled
%else
    %define arg_storage_sheepdog -Dstorage_sheepdog=disabled
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster -Dstorage_gluster=enabled -Dglusterfs=enabled
%else
    %define arg_storage_gluster -Dstorage_gluster=disabled -Dglusterfs=disabled
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs -Dstorage_zfs=enabled
%else
    %define arg_storage_zfs -Dstorage_zfs=disabled
%endif

%if %{with_storage_vstorage}
    %define arg_storage_vstorage -Dstorage_vstorage=enabled
%else
    %define arg_storage_vstorage -Dstorage_vstorage=enabled
%endif

%if %{with_numactl}
    %define arg_numactl -Dnumactl=enabled
%else
    %define arg_numactl -Dnumactl=disabled
%endif

%if %{with_numad}
    %define arg_numad -Dnumad=enabled
%else
    %define arg_numad -Dnumad=disabled
%endif

%if %{with_fuse}
    %define arg_fuse -Dfuse=enabled
%else
    %define arg_fuse -Dfuse=disabled
%endif

%if %{with_sanlock}
    %define arg_sanlock -Dsanlock=enabled
%else
    %define arg_sanlock -Dsanlock=disabled
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone -Dfirewalld_zone=enabled
%else
    %define arg_firewalld_zone -Dfirewalld_zone=disabled
%endif

%if %{with_netcf}
    %define arg_netcf -Dnetcf=enabled
%else
    %define arg_netcf -Dnetcf=disabled
%endif

%if %{with_wireshark}
    %define arg_wireshark -Dwireshark_dissector=enabled
%else
    %define arg_wireshark -Dwireshark_dissector=disabled
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=enabled -Dlibiscsi=enabled
%else
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=disabled -Dlibiscsi=disabled
%endif

%if %{with_libssh}
    %define arg_libssh -Dlibssh=enabled
%else
    %define arg_libssh -Dlibssh=disabled
%endif

%if %{with_libssh2}
    %define arg_libssh2 -Dlibssh2=enabled
%else
    %define arg_libssh2 -Dlibssh2=disabled
%endif

%if %{with_storage_misc}
    %define arg_storage_misc -Dstorage_lvm=enabled -Dstorage_iscsi=enabled -Dstorage_scsi=enabled -Dstorage_disk=enabled -Dstorage_mpath=enabled
%else
    %define arg_storage_misc -Dstorage_lvm=disabled -Dstorage_iscsi=disabled -Dstorage_scsi=disabled -Dstorage_disk=disabled -Dstorage_mpath=disabled
%endif

%if %{with_secret}
    %define arg_secret -Ddriver_secrets=enabled
%else
    %define arg_secret -Ddriver_secrets=disabled
%endif

%if %{with_vz}
    %define arg_vz -Ddriver_vz=enabled
%else
    %define arg_vz -Ddriver_vz=disabled
%endif

%if %{with_vzct}
    %define arg_vzct -Ddriver_vzct=enabled
%else
    %define arg_vzct -Ddriver_vzct=disabled
%endif

%if %{with_vcmmd}
    %define arg_vcmmd -Dvcmmd=enabled
%else
    %define arg_vcmmd -Dvcmmd=disabled
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager -Dpackager="%{who}, %{when}, %{where}"
%define arg_packager_version -Dpackager_version="%{release}"

%define arg_selinux_mount -Dselinux_mount="/sys/fs/selinux"

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%meson \
           -Drunstatedir=%{_rundir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           -Dsasl=enabled \
           -Dpolkit=enabled \
           -Ddriver_libvirtd=enabled \
           -Ddriver_remote=enabled \
           -Ddriver_test=enabled \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           %{?arg_vz} \
           %{?arg_vzct} \
           -Ddriver_bhyve=disabled \
           -Ddriver_ch=disabled \
           -Dremote_default_mode=legacy \
           -Ddriver_interface=enabled \
           -Ddriver_network=enabled \
           -Dstorage_fs=enabled \
           %{?arg_storage_iscsi_direct} \
           %{?arg_storage_misc} \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           %{?arg_storage_vstorage} \
           %{?arg_numactl} \
           %{?arg_numad} \
           -Dcapng=enabled \
           %{?arg_fuse} \
           %{?arg_netcf} \
           %{?arg_vcmmd} \
           -Dselinux=enabled \
           %{?arg_selinux_mount} \
           -Dapparmor=disabled \
           -Dapparmor_profiles=disabled \
           -Dsecdriver_apparmor=disabled \
           -Dudev=enabled \
           -Dyajl=enabled \
           %{?arg_sanlock} \
           -Dlibpcap=enabled \
           -Dlibnl=enabled \
           -Daudit=enabled \
           -Ddtrace=enabled \
           -Dfirewalld=enabled \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           %{?arg_libssh} \
           %{?arg_libssh2} \
           %{?arg_secret} \
           -Dpm_utils=disabled \
           -Dnss=enabled \
           %{arg_packager} \
           %{arg_packager_version} \
           -Dqemu_user=%{qemu_user} \
           -Dqemu_group=%{qemu_group} \
           -Dtls_priority=%{tls_priority} \
           %{?enable_werror} \
           -Dexpensive_tests=enabled \
           -Dinit_script=systemd \
           -Ddocs=enabled \
           -Dtests=enabled \
           -Drpath=disabled \
           %{?arg_login_shell}

%meson_build

%install
rm -fr %{buildroot}

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%meson_install

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %%files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %%post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{arches_systemtap_64bit}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%check
%if 0
# Building on slow archs, like emulated s390x in Fedora copr, requires
# raising the test timeout
VIR_TEST_DEBUG=1 %meson_test --no-suite syntax-check --timeout-multiplier 10
%endif

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon
%global post_units \\\
        virtlockd.socket virtlockd-admin.socket \\\
        virtlogd.socket virtlogd-admin.socket \\\
        libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket \\\
        libvirtd-tcp.socket libvirtd-tls.socket \\\
        libvirtd.service \\\
        libvirt-guests.service

%systemd_post %post_units

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%global preun_units \\\
        libvirtd.service \\\
        libvirtd-tcp.socket libvirtd-tls.socket \\\
        libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket \\\
        virtlogd.socket virtlogd-admin.socket virtlogd.service \\\
        virtlockd.socket virtlockd-admin.socket virtlockd.service \\\
        libvirt-guests.service

%systemd_preun %preun_units

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service virtlogd.service >/dev/null 2>&1 || :
fi
%systemd_postun libvirt-guests.service

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # See if user has previously modified their install to
    # tell libvirtd to use --listen
    grep -E '^LIBVIRTD_ARGS=.*--listen' /etc/sysconfig/libvirtd 1>/dev/null 2>&1
    if test $? = 0
    then
        # Then lets keep honouring --listen and *not* use
        # systemd socket activation, because switching things
        # might confuse mgmt tool like puppet/ansible that
        # expect the old style libvirtd
        /bin/systemctl mask \
                libvirtd.socket \
                libvirtd-ro.socket \
                libvirtd-admin.socket \
                libvirtd-tls.socket \
                libvirtd-tcp.socket >/dev/null 2>&1 || :
    else
        # Old libvirtd owns the sockets and will delete them on
        # shutdown. Can't use a try-restart as libvirtd will simply
        # own the sockets again when it comes back up. Thus we must
        # do this particular ordering, so that we get libvirtd
        # running with socket activation in use
        /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1
        if test $? = 0
        then
            /bin/systemctl stop libvirtd.service >/dev/null 2>&1 || :

            /bin/systemctl try-restart \
                    libvirtd.socket \
                    libvirtd-ro.socket \
                    libvirtd-admin.socket >/dev/null 2>&1 || :

            /bin/systemctl start libvirtd.service >/dev/null 2>&1 || :
        fi
    fi
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    sed -e "s/${orig_sub}/${sub}/g" \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%if %{with_vzct}
%post daemon-vzct
/usr/sbin/modprobe vzevent
/bin/systemctl start vz.service >/dev/null 2>&1 ||:
%endif

%post daemon-config-nwfilter
for datadir_file in %{_datadir}/libvirt/nwfilter/*.xml; do
  sysconfdir_file=%{_sysconfdir}/libvirt/nwfilter/$(basename "$datadir_file")
  if [ ! -f "$sysconfdir_file" ]; then
    # libvirt saves these files with mode 600
    install -m 0600 "$datadir_file" "$sysconfdir_file"
  fi
done
# Make sure libvirt picks up the new nwfilter defininitons
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS.rst NEWS.rst README.rst
%doc libvirt-docs/*

%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtproxyd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_rundir}/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_bindir}/virt-ssh-helper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtproxyd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%{_mandir}/man1/virt-admin.1*
%{_mandir}/man1/virt-host-validate.1*
%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man8/virtproxyd.8*
%{_mandir}/man7/virkey*.7*

%{_bindir}/virt-host-validate
%{_bindir}/virt-admin
%{_datadir}/bash-completion/completions/virt-admin

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/sysconfig/virtinterfaced
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%attr(0755, root, root) %{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so
%{_mandir}/man8/virtinterfaced.8*

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/sysconfig/virtnetworkd
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_rundir}/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so
%{_mandir}/man8/virtnetworkd.8*

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/sysconfig/virtnodedevd
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so
%{_mandir}/man8/virtnodedevd.8*

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/sysconfig/virtnwfilterd
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_rundir}/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so
%{_mandir}/man8/virtnwfilterd.8*

%if %{with_secret}
%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/sysconfig/virtsecretd
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtsecretd
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so
%{_mandir}/man8/virtsecretd.8*
%endif

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/sysconfig/virtstoraged
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%attr(0755, root, root) %{_sbindir}/virtstoraged
%if %{with_storage_misc}
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%endif
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so
%{_mandir}/man8/virtstoraged.8*

%if %{with_storage_misc}
%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so
%endif

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_storage_vstorage}
%files daemon-driver-storage-vstorage
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_vstorage.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/sysconfig/virtqemud
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%attr(0755, root, root) %{_sbindir}/virtqemud
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%if 0%{?_aci_build:1}
    %exclude %{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%else
    %dir %attr(0700, root, root) %{_sysconfdir}/libvirt/hooks/qemu.d/
    %{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_rundir}/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0730, tss, tss) %{_localstatedir}/log/swtpm/libvirt/qemu/
%{_bindir}/virt-qemu-run
%{_mandir}/man1/virt-qemu-run.1*
%{_mandir}/man8/virtqemud.8*
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/sysconfig/virtlxcd
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_rundir}/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%{_mandir}/man8/virtlxcd.8*
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/sysconfig/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%attr(0755, root, root) %{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_rundir}/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%{_mandir}/man8/virtxend.8*
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/sysconfig/virtvboxd
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%{_mandir}/man8/virtvboxd.8*
%endif

%if %{with_vz}
%files daemon-driver-vz
%{_libdir}/%{name}/connection-driver/libvirt_driver_vz.so
%config(noreplace) %{_sysconfdir}/sysconfig/virtvzd
%config(noreplace) %{_sysconfdir}/libvirt/virtvzd.conf
%{_datadir}/augeas/lenses/virtvzd.aug
%{_datadir}/augeas/lenses/tests/test_virtvzd.aug
%{_unitdir}/virtvzd.service
%{_unitdir}/virtvzd.socket
%{_unitdir}/virtvzd-ro.socket
%{_unitdir}/virtvzd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvzd
%{_mandir}/man8/virtvzd.8*
%endif

%if %{with_vzct}
%files daemon-driver-vzct
%defattr(-, root, root)
%{_libdir}/%{name}/connection-driver/libvirt_driver_vzct.so
%config(noreplace) %{_sysconfdir}/sysconfig/virtvzctd
%config(noreplace) %{_sysconfdir}/libvirt/virtvzctd.conf
%{_datadir}/augeas/lenses/virtvzctd.aug
%{_datadir}/augeas/lenses/tests/test_virtvzctd.aug
%{_unitdir}/virtvzctd.service
%{_unitdir}/virtvzctd.socket
%{_unitdir}/virtvzctd-ro.socket
%{_unitdir}/virtvzctd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvzctd
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_vz}
%files daemon-vz
%endif

%if %{with_vzct}
%files daemon-vzct
%defattr(-, root, root)
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate

%{_datadir}/bash-completion/completions/virsh

%files libs -f %{name}.lang
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif

%{_datadir}/libvirt/schemas/*.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%{_libexecdir}/virt-login-shell-helper
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/libvirt-domain-backup.h
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Wed Feb 02 2022 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-7.6.0-2.vz9.14.3
- FIXUP: vzct 2: intoduce migration

* Wed Feb 02 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.14.2
- qemu: get agent right after availability check #PSBM-138291

* Thu Jan 27 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.14.1
- qemu: don't turn on evmcs in define hook for AMD #PSBM-138013

* Tue Jan 25 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.14
- FIXUP: fix off by one in qemuGetVzScriptCommand introduced by rebase #PSBM-138001

* Tue Jan 25 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.13
- REVERT: qemu: support snapshots done with Vz downstream patches
- REVERT: schema: snapshot: add persistent domain config #PSBM-137950
- FIXUP: mention modern element name for inactive domain config
- FIXUP: simplify stopping all block exports #PSBM-126462

* Mon Jan 24 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.12
- FIXUP: fix qemuMigrationChardevPlug error path
- FIXUP: fix ABBA potential deadlock on access to migrating table
- FIXUP: use migration data instead of simple bool
- vzct: add domain state info to the cookie
- vzct: reserve vnc port in prepare state #PSBM-107443

* Tue Jan 18 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.11
- FIXUP:  vzct 2: drop job on client disconnection during migration

* Mon Jan 17 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.10
- FIXUP: vzct: check changes in active/inactive xml are supported on migration #PSBM-136644
- FIXUP: vzct: check changes in active/inactive xml are supported on migration

* Fri Jan 14 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.9
- qemu: temporary don't show default audio in public xml PSBM-137622

* Fri Jan 14 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.8
- FIXUP: nwfilter: add vz specific filters #PSBM-137593

* Thu Jan 13 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.7
- api: report extraId in domain xml #PSBM-136251
- FIXUP: handle NULL network #PSBM-137453

* Wed Jan 12 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.6
- DROP: qemu: support file chardev append option on hotplug/change
- FIXUP: qemu: migration: add cookie parts for vstorage chardevs
- DROP: qemu: support logfile option on chardev hotplug/change

* Wed Jan 12 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.5
- FIXUP:  qemu: add exec with true streams
- FIXUP: api,qemu: add latency histogram

* Tue Jan 11 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.4
- vzct: update UUID if it is changed in libvzctl #PSBM-136737
- qemu: implement changing VNC port on a running VM #PSBM-136282

* Mon Jan 10 2022 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.3
- DROP: backport fixup: remote: implement virDomainGetGuestInfo
- DROP: upgrade: tap: use multiqueue to make upgrade possible
- DROP: qemu: add vmbus-bridge device if hv-scsi present
- DROP: pull: api: add API for pull (external) backups
- DROP: pull: api: add driver based implementation
- DROP: pull: remote: add pull backup API implementation
- DROP: pull: conf: add block snapshot format/parse
- DROP: pull: conf: add export conf def/parsing
- DROP: pull: qemu: implement export start/stop
- DROP: api,qemu: add latency histogram
- DROP: hubapi: remote: implement listing domains
- DROP: hubapi: remote: support domain- API calls
- DROP: FIXUP: vz: misc fixups
- DROP: nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- DROP: qemu: caps: invalidate kvm capable qemu binaries on every restart #PSBM-88418
- DROP: exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- DROP: exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- DROP: conf: remove features unknown to qemu (related to #PSBM-96228)
- DROP: agent: increase default timeout from 5s to 30s #PSBM-97240
- DROP: conf: add debugcon chardev guest interface
- DROP: qemu: implement debugcon chardev
- DROP: qemu: autoadd iobase to debugcon chardev
- DROP: conf: add replug option for usb hostdev
- DROP: FIXUP: qemu: adopt latency impl to new qemu #PSBM-97535
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support stats API #PSBM-104070
- DROP: FIXUP: vzct 2: support stats API
- DROP: vzct 2: support snapshots
- DROP: doc: adopt README.md for Virtuozzo
- DROP: FIXUP: host usb device replug docs
- DROP: qemu: add vcmmd support #PSBM-106483
- DROP: FIXUP: qemu: add vcmmd support #PSBM-106483
- DROP: vzct 2: drop job on client disconnection during migration
- DROP: Changes for support DNS configuration #PSBM-106778
- DROP: FIXUP: exec: kill orphans on migration destination
- DROP: qemu: migration: add cookie parts for vstorage chardevs
- DROP: vstorage migration: add vstorage disks info to cookie
- DROP: vstorage migration: add vstorage nvram info to cookie
- DROP: qemu: cleanup tmp snapshot #PSBM-106875
- DROP: vstorage migration: keep nvram tmp snapshot in status
- DROP: qemu/api: support min_guarantee as fraction of balloon #PSBM-126684
- DROP: FIXUP: upgrade: tap: use multiqueue to make upgrade possible
- DROP: nwfilter: don't add symmetric record for policy rule #PSBM-126688
- DROP: qemu: capabilities: Add capability for the 'copy-mode' arg of 'drive-mirror' command #PSBM-97507
- DROP: qemu: support setting net params thru prl_nettool #PSBM-129743
- DROP: vzct 2: add destination pool info to migration cookie
- DROP: vzct 2: migration: check storage pool alignment on src and dest
- DROP: FIXUP: Fix fox multiple ip #PSBM-132727
- DROP: vzct: support setting default gateway #PSBM-133497
- DROP: qemu: don't run direct monitor commands as query
- DROP: FIXUP: fix parsing block export conf typo
- DROP: FIXUP: fix typo in hub patch
- DROP: vz: fix compiler errors on vz9
- DROP: FIXUP: include libvirt-domain-backup.h in build
- vz: compile fixes
- upgrade: tap: use multiqueue to make upgrade possible
- qemu: add vmbus-bridge device if hv-scsi present
- pull: api: add API for pull (external) backups
- pull: api: add driver based implementation
- pull: remote: add pull backup API implementation
- pull: conf: add block snapshot format/parse
- pull: conf: add export conf def/parsing
- pull: qemu: implement export start/stop
- api,qemu: add latency histogram
- hubapi: remote: implement listing domains
- hubapi: remote: support domain- API calls
- nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- qemu: caps: invalidate kvm capable qemu binaries on every restart #PSBM-88418
- exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- conf: remove features unknown to qemu (related to #PSBM-96228)
- agent: increase default timeout from 5s to 30s #PSBM-97240
- conf: add debugcon chardev guest interface
- qemu: implement debugcon chardev
- qemu: autoadd iobase to debugcon chardev
- conf: add replug option for usb hostdev
- vzct 2: add basic structure and listing
- vzct 2: support stats API #PSBM-104070
- vzct 2: support snapshots
- doc: adopt README.md for Virtuozzo
- qemu: add vcmmd support #PSBM-106483
- vzct 2: drop job on client disconnection during migration
- Changes for support DNS configuration #PSBM-106778
- qemu: migration: add cookie parts for vstorage chardevs
- vstorage migration: add vstorage disks info to cookie
- vstorage migration: add vstorage nvram info to cookie
- qemu: cleanup tmp snapshot #PSBM-106875
- vstorage migration: keep nvram tmp snapshot in status
- qemu/api: support min_guarantee as fraction of balloon #PSBM-126684
- nwfilter: don't add symmetric record for policy rule #PSBM-126688
- qemu: capabilities: Add capability for the 'copy-mode' arg of 'drive-mirror' command #PSBM-97507
- qemu: support setting net params thru prl_nettool #PSBM-129743
- vzct 2: add destination pool info to migration cookie
- vzct 2: migration: check storage pool alignment on src and dest
- vzct: support setting default gateway #PSBM-133497
- qemu: don't run direct monitor commands as query

* Wed Dec 29 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.2
- FIXUP: include libvirt-domain-backup.h in build

* Wed Dec 29 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-7.6.0-2.vz9.1
- vz: fixes after renaming Parallels to Virtuozzo in sdk
- backport fixup: remote: implement virDomainGetGuestInfo
- iohelper: truncate large chunks on write #PSBM-70840
- Added new flag VIR_DOMAIN_CREATE_USER
- conf: tune connection parameters for Virtuozzo #PSBM-92128
- Set LimitCORE=infinity in libvirtd.service
- conf: add 'format' attribute to domain/os/nvram element
- qemu: don't pause vm when creating internal snapshot
- vz: use /etc/machine-id as host uuid
- qemu: log: log monitor events by default
- relax network adapter config checking (bug #PSBM-54596 fix)
- qemu: v2 fix reboot scenario (bugs #PSBM-41956 #PSBM-54756 fix)
- vz: set virtio as default network model
- qemu: fix crash on getting block stats for empty cdrom
- vz: rework the way we get perfomance counters
- vz: use cached statistics for a predefined period
- vz: don't subscribe to perfomance counters
- vz: cleanup: delete unused constant definition
- vz: don't create driver object during daemon initialization
- conf/qemu: add hv-scsi model to scsi controllers
- vz: add domain name info in error message
- qemu: simplify graphics port releasing
- upgrade: support local p2p migration
- object: add shared lock option to lockable
- upgrade: initial implementation
- upgrade: don't show events from not face process
- upgrade: start target domain with source id
- cgroup: use id+generation for machine cgroup name if last is not 0
- upgrade: fix id clashes for domain private paths etc
- conf: accept path in virDomainSaveXML
- upgrade: store generation in status file
- dom list: refactor: reuse code in find functions
- upgrade: return face domain from domlist
- migration: support --release-ram
- migration: add --postcopy-start to start postcopy immediately
- upgrade: virtlogd: handle output for one path from 2 qemu
- upgrade: pass live config to target
- upgrade: don't generate seclabel again on upgrade
- upgrade: handle auto generated char dev unix paths
- upgrade: vnc: do not regenerate graphics for target process
- upgrade: vnc: factor out building vnc opts
- upgrade: vnc: make vnc upgrade possible
- upgrade: vnc: keep vnc state across upgrade
- qemu: add local_migration param to qemu.conf
- upgrade: tap: use multiqueue to make upgrade possible
- upgrade: network iface: keep actual net
- upgrade: snapshots: support snapshots
- upgrade: don't assign dev aliases on upgrade
- qemu: drop acquiring job condition on removing vm from list
- qemu: fix one more race on undefining and create
- upgrade: restart pending jobs after upgrade
- upgrade: fix domain lookup in old face removing phase
- upgrade: make correct reconnection of upgrade
- upgrade: set used ports only for face
- upgrade: support for server backends for serial chardevs
- qemu.conf: set upper limit for vnc/spice ports to 6900
- upgrade: don't reject upgrade if hostname is localhost
- qemu: wait indefinetly when acquiring job condition in event handlers
- upgrade: close agent channel befor postcopy with release ram
- upgrade: use unique name for pidfiles across upgrades
- qemu: remove time limit on waiting qemu disappearence on EOF
- qemu: add vmbus-bridge device if hv-scsi present
- qemu: agent: stop io loop effectively on eof or error
- upgrade: fix crash if vm newdef is empty
- libvirtd: tune OOMScoreAdjust
- qemu: revert fb2cd32c
- qemu: monitor: check monitor not closed on send
- vz: remove domain uuid check on migration #PSBM-43767
- qemu: support hv-net interface models
- nwfilter: fix deadlock on firewalld restart/reload
- vz: allow to start vz driver without host cache info
- qemu: snapshot: revert upstream 9e2465834 #PSBM-76749
- api qemu: add block pull compress option #PSBM-73618
- qemu: include nvram into offline snapshots
- qemu: fail making internal snapshots with non qcow2 nvram
- util: virFDStreamConnectUNIX: add missing error report
- util: add 30s connection timeout to virFDStreamConnectUNIX
- qemu: use job to make domain responsive on qemuDomainOpenChannel
- qemu: wait qemu death indefinetely on domain stop #PSBM-70541
- pull: api: add API for pull (external) backups
- pull: api: add driver based implementation
- pull: remote: add pull backup API implementation
- pull: qemu: monitor: add commands for backup
- pull: conf: add block snapshot format/parse
- pull: virsh: add block snapshot create/delete
- qemu: store guest visible disk size from qemu monitor block info
- pull: conf: add block snaphots to status file
- pull: qemu: block snapshots basic implementation
- pull: qemu: support disks quiesce
- pull: qemu: add block snapshots listing
- pull: qemu: support block snapshot dumpxml
- pull: qemu: monitor: add cmd to delete nbd export
- pull: conf: add export conf def/parsing
- pull: qemu: implement export start/stop
- pull: qemu: don't delete snapshot while disks are exported
- util: hash: remove const from value in kv pair type
- pull: add autodelete option for creating block snapshots #VSTOR-22687
- pull: stop exporting snapshot on snapshot autodelete
- pull: qemu: monitor: add bitmap commands
- pull: pull: add dirty bitmap on creating snapshot
- pull: add command to remove checkpoint
- pull: qemu: remove checkpoint on autodelete
- pull: qemu: load bitmaps on domain start
- pull: qemu: monitor: add command to export bitmap
- pull: export bitmap
- pull: migrate checkpoints
- pull: qemu: validate snapshot name
- pull: qemu: add exportable paused start
- pull: add TLS to block export
- pull: add relaxng
- pull: add autoport on export
- qemu: add unmap stats to all domain stats
- api,qemu: add latency histogram
- hubapi: remote: implement listing domains
- hubapi: remote: support domain- API calls
- hubapi: remote: support domain lookup functions
- hubapi: remote: support {create,define}xml API
- hubapi: remote: support domain events
- hubapi: remote: support virConnectGetCapabilities
- hubapi: remote: return vz connection type if vz is in hub
- hubapi: remote: return vz connection type if vzct is in hub
- hubapi: find appropriate connection for domain xml #VZOS-1704
- vz: add option to resize filesystems thur virDomainBlockResize
- FIXUP: vz: misc fixups
- vz: support virDomainGetBlockInfo in driver
- api/qemu: introduce hv-vss freeze/thaw
- pull: disable risky cases with RW NBD exports
- qemu: fix attach/detach char devices to use guest device id
- conf: remove none console target type check from  virDomainDefAddConsoleCompat
- conf: remove none console target type check from virDomainDefFormatInternal
- conf: remove none console target type check from virDomainSkipBackcompatConsole
- qemu: update compat console on attach first serial device
- qemu: support updating backend of serial device
- pull: qemu: add option to export last checkpoint
- portallocator: print warn on releasing not used port
- netlink: remove watch before closing fd
- qemu: monitor: set error flag even in OOM conditions
- utils: export virCopyError
- qemu: fix domain object wait to handle monitor errors
- qemu: fix races in beingDestroyed usage
- lib: provide error message in new blockjob event
- qemu: agent: incapsulate vm reference management
- qemu: agent: remove unconvinient destroy callback
- qemu: agent: factor out code to open channel
- qemu: agent: remove useless signalling
- qemu: agent: do not take moninor ref in IO callback
- qemu: agent: remove qemuAgentNotifyCloseLocked
- qemu: agent: don't retry first sync message if monitor closed
- qemu: agent: better error message for disconnected agent
- qemu: agent: give same message on monitor errors
- qemu: agent: move monitor error check to better place
- qemu: domain: add name arg to qemuFindAgentConfig
- qemu: agent: prepare serial event handler for aux channel
- rpc: support multiple streams on client side
- rpc: fix to support multiple streams
- rpc: close stream on receive errors
- rpc: pass original stream recv/send error
- qemu: add exec with true streams
- tools: stop event loop before closing connection
- virsh: don't print \n footer for x-exec
- misc: remove some invalid G_GNUC_WARN_UNUSED_RESULT
- nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- pci: more verbose error in virPCIGetDeviceAddressFromSysfsLink
- daemon: purge logs for domains removed more than month ago
- remote: fix SIGSEGV on closing client connection
- pull: don't destroy vm if it has block snapshots or exports
- qemu: destroy domain on monitor EOF anyway
- pull: log merge/rename bitmap operations
- api/qemu: add move nvram API
- qemu: add option to update disk copy_on_read live #VSTOR-10895
- qemu: add qcow2 cache size policy
- tools: move virshGetEscapeChar to utils
- virsh: support in, err, out as regular files
- qemu: support interactive exec #PSBM-91739
- qemu: remove sanity check in qemuMonitorJSONDiskNameLookupOne
- exec: provide tty params on exec when possible
- rpc: allow comments in prototol description
- remote: leave stub comment for 16/virDomainGetOSInfoX
- libvirt: add new virDomainCommandXSetParams API
- exec: handle client window size change when interactive
- qemu: add hci value (128MiB) to qcow2 disk cache policy
- upgrade: handle firewall rules #PSBM-90137
- qemu: caps: invalidate kvm capable qemu binaries on every restart #PSBM-88418
- cgroup: blacklist criu temporary mounts #PSBM-90471
- qemu: imply qcow2 format for backing store if not set
- rpc: client: fix race on stream error and stream creation
- exec: virsh: support redirection to special chardevs #PSBM-91601
- exec: restore std streams' flags on become foreground #PSBM-91602 #PSBM-93755
- rpc: client: stream: notify streams of closing connection
- Revert: log: actually do substring matches with fnmatch #PSBM-92872
- pull: clean autodelete snapshots on daemon restart
- qemu: agent: add code -2 when guest exec pid  not found
- qemu: don't wait job in cleanup thread
- exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- qemu: seccomp: don't turn it on by default #PSBM-93004
- qemu: ignore disabled arch-facilities in configs #PSBM-92991
- qemu: support explicit disk backing in input #VSTOR-21806 #VSTOR-21934
- logging: remove watch before closing fd in virLogHandlerLogFileFree #PSBM-93003
- qemu: don't log error for disk sources not supporting getting offline stats (nbd)
- qemu: don't log error when monitor EOF is expected #PSBM-93003
- qemu: agent: don't log error when monitor EOF is expected
- qemu: agent aux: don't log error when monitor EOF is expected
- qemu: qemuBlockDiskDetectNodes: get name if one is known
- backup: copy bitmaps to top image on snapshot
- virDomainObjListAddObjLocked: Don't expect vm->def to be set
- virDomainObjListAddLocked: Set vm->def only in success path
- virDomainObjListAdd: Leave def assigning as an exercise for caller
- virDomainObjListAdd: Remove unused flag
- qemu: Grab modify job for changing domain XML
- qemu_domain: Allow qemuDomainObjListAdd to keep job upon return
- qemu: release job on cleanup path
- qemu: snapshot revert: reuse common cleanup code
- qemu: support snapshots done with Vz downstream patches
- schema: snapshot: add persistent domain config
- docs: add persistent config to snapshot xml description
- conf: snapshot: check domain name on redefine
- conf: snapshot: support persistent config on redefine
- qemu: add option to close cdrom tray #PSBM-95870
- conf: remove features unknown to qemu (related to #PSBM-96228)
- agent: increase default timeout from 5s to 30s #PSBM-97240
- qemu: introduce qemuDomainChrSerialTargetModel
- conf: add debugcon chardev guest interface
- qemu: make irq optional when formatting the ISA address
- qemu: implement debugcon chardev
- qemu: autoadd iobase to debugcon chardev
- api/qemu: add pause/resume for blockjobs
- qemu: agent: log total tx/rx for streams
- debug: print 'thr a a bt' in log when taking some mutex takes much time
- qemu: monitor: throttle logging BLOCK_IO_ERROR events #VSTOR-26657
- qemu: ignore delayed EOF events from previous VM incarnations #ABR-243123
- qemu: don't fail pausing block job if it is missing #VSTOR-21176
- qemu: migration: implement shared workaround #VSTOR-11398
- conf: handle empty string in interface target name #PSBM-97765
- conf: add replug option for usb hostdev
- qemu: track hostdev delete intention
- qemu: support host usb device unplug
- qemu: support usb hostdev plugging back
- qemu: handle host usb device add/del udev events
- qemu: handle libvirtd restart after host usb device unplug
- qemu: handle race on device deletion and usb host device plugging
- qemu: hotplug: update device list on device deleted event
- qemu: handle host usb device plug/unplug when libvirtd is down
- qemu: don't mess with non mandatory hostdevs on reattaching
- qemu: handle detaching of unplugged hostdev
- conf: parse hostdev missing flag
- backup: don't keep bitmaps in base image on snapshots #VSTOR-23605
- backup: copy bitmaps down on active block commit #VSTOR-23605
- qemu: support new qemu without nbd-server-add-bitmap command #VSTOR-27428
- fix for "virDomainObjListAdd: Leave def assigning as an exercise for caller" #PSBM-98834
- qemu: handle storage/virtlogd hanging #VSTOR-27947
- qemu: add option to process offloaded legacy blockjob event ealier #PSBM-121858
- qemu: reconnect: precreate legacy blockjobs
- qemu: remove extra block job finalize on reconnect
- qemu: remove stale cleanup in qemuProcessRefreshLegacyBlockjob
- qemu: add note for outdated legacy block job events
- FIXUP: qemu: use autoptr in qemuProcessRefreshLegacyBlockjobs
- qemu: refresh backing chain after block job reconnection
- qemu: move code that depends on backing chain appropriately
- qemu: fix race on legacy block completion and quering stats
- qemu: sync backing chain update and completed blockjob #VSTOR-28575 #VSTOR-34322
- qemu: support 'preserve' option for 'on_poweroff'
- qemu: add reconnect params for nbd network disks #VSTOR-28845
- qemu: kill partially started domain immediately on reconnect #VSTOR-29393
- qemu: disable snapshot explicitly when block snapshot is in progress #VSTOR-29840
- asan: workaround sanitizer issues with clone(2)
- asan: configure to coredump on signals
- hubapi: workaround virURIFormat degradation in vz8
- qemu: adopt nodename detection to backup filter node
- FIXUP: qemu: adopt latency impl to new qemu #PSBM-97535
- qemu: turn on keep alive for nbd disk migration #PSBM-97768
- conf: add more options to save config filename
- conf: allow NULL callback in virDomainObjListRename
- conf: support extra id in domain list
- vzct 2: add basic structure and listing
- virsystemd: workaround race on systemd-machined idle shutdown #PSBM-102137
- rpc: add timeout on connection #VSTOR-32643
- conf: support light vcpus and unlimitied number
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: support iolimits #PSBM-104069
- vzct 2: add misc API
- vzct 2: support stats API #PSBM-104070
- qemu: use explicit backing mode only if there is nbd in backing #PSBM-104929
- qemu: optimize qemuOpenFileAs for reads #VSTOR-34701
- Add qemu hook suitable to handle device hotplug/hotunplug #PSBM-104793
- FIXUP: vzct 2: support stats API
- util: add virFileRead function
- conf: moment: remember if name is autogenerated
- vzct 2: support snapshots
- xml: add venet0 network interface type
- vzct 2: support venet0 network interface #PSBM-105548
- qemu: ignore allow_disk_format_probing #PSBM-105558
- upgrade: don't mess with security labels #PSBM-105674
- qemu: pass rememberOwner during update #PSBM-105674
- qemu: auto load vhost-vsock module #PSBM-106171
- virsh: handle snapshots with domain state unknown
- util: add means to detect vstorage filesystem
- security: exclude vstorage from labelling #PSBM-105985
- vzct 2: don't try virDomainLookupByID
- qemu: caps: use more precise condition when to use CAP_DAC_OVERRIDE #PSBM-106271
- doc: adopt README.md for Virtuozzo
- Add new type of storage pool for Windows Storage Spaces (WSS) #PSBM-106275
- virsh: don't shout if virDomainGetJobInfo is not supported
- vzct 2: save disks uuid in config/status files
- vzct 2: intoduce migration
- conf: add auto mininal memory guarantee mode
- vzct 2: support memory guarantees #PSBM-106482
- FIXUP: host usb device replug docs
- vzct 2: mark supported xml parts in domain/snapshot docs #PSBM-106576
- qemu: add vcmmd support #PSBM-106483
- FIXUP: qemu: add vcmmd support #PSBM-106483
- qemu: agent: disable blocking calls to agent #PSBM-107669
- vzct 2: add jobs support for everything except migration
- vzct 2: support jobs during migration #PSBM-107444
- vzct 2: drop job on client disconnection during migration
- Changes for support DNS configuration #PSBM-106778
- vzct 2: add lifecycle events #PSBM-107730
- vzct 2: support getting stats for migration #PSBM-107763
- vzct 2: support aborting domain job API #PSBM-107446
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: monitor: bring add/remove fd commands back
- qemu: don't leave descriptors in fdsets after process startup #PSBM-108299
- qemu: support file chardev append option on hotplug/change
- qemu: support logfile option on chardev hotplug/change
- FIXUP: exec: kill orphans on migration destination
- qemu: migration: add cookie parts for vstorage chardevs
- logging: close backing file on eof on drain
- qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- qemu: migration: support changing chardev backend with virtlogd
- logging: handle race on drain and closing in event loop
- logging: allow NULL to inode and offset out args on drain
- qemu: migration: detect shared vstorage chardevs
- vstorage: support migrating with chardevs on vstorage #PSBM-106373
- qemu: add vstorage chardev tmpfile names to status file
- qemu: sync chardevs unplugged status on reconnect
- qemu: cleanup up vstorage chardevs after libvirtd crash
- qemu: drain file chardevs on domain process stop
- vstorage migration: introduce virDomainMigrateVstorageCommit
- vstorage migration: add vstorage snapshot commit phase
- vstorage migration: add vstorage disks info to cookie
- qemu: add vstorage snapshot utility functions
- vstorage migration: add vstorage nvram info to cookie
- qemu: add nvram block job support
- vstorage migration: add vstorage snapshot commit
- qemu: introduce qemuDomainCreateImage
- vstorage migration: main patch #PSBM-106202
- vstorage migration: support p2p
- vstorage: load bitmaps from base image for tmp snapshot #PSBM-123771
- vstorage migration: track valid temporary snapshot
- vstorage migration: resolve valid tmp snapshot on domain start
- vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: don't parse tmp snapshot commit job in status
- vstorage migration: keep snapshot info in status
- vstorage migration: add dst cleanup after disconnection
- vstorage migration: determine valid snapshot on crash/disconnections
- qemu: migration: fix missing owner on disconnection cleanup
- qemu: cleanup tmp snapshot #PSBM-106875
- qemu: support nvram block job on reconnect
- vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- qemu: add filename to qemuMonitorGetBlockInfo
- vstorage migration: handle completed tmp snapshot commit on reconnect #PSBM-121261
- nwfilter: add vz specific filters #PSBM-121477
- vstorage migration: keep nvram tmp snapshot in status
- vstorage migration: adopt qemuDomainGetStatsOneBlock to tmp snapshot
- vstorage migration: fix active block stats with tmp snapshot #PSBM-121042
- vstorage migration: fix inactive block stats with tmp snapshot #PSBM-121042
- vstorage migration: handle short time EBUSY on commit #PSBM-122012
- api: add stub for virDomainBlockCheckpointXSwitch
- api: add VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO
- tools: support memtune --min-guarantee-auto-vz
- qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters #PSBM-121895
- Fix for possibility to use inituser without initgroup #PSBM-122225
- vzct 2: support autostarting domains #PSBM-121587
- qemu: turn on postcopy to migrate bitmaps #PSBM-100171
- qemu: fix guest visible disk id if serial is long #VSTOR-38958
- qemu: fix managed pr-helper tear down on chaning device media #PSBM-123337
- doc: document virsh commands for block snaphots/exports #PSBM-122231
- vz: fix after Parallels to Virtuozzo rename #PSBM-124533
- virsh: fix Vstorage support reporting
- exec: don't print errors to stderr #PSBM-124629
- vzct 2: implement exec API #PSBM-106206
- virsh: don't call virDomainGetGuestInfo for vzct interactive exec
- daemon: switch off autoshutdown #VSTOR-40335
- api: fix documentation typo
- misc: add bypass cache flag for block snapshot creation #PSBM-124764
- vzct: Support setting memory for active CT #PSBM-122489
- vzct: Support setting cpu num for active CT #PSBM-122517
- docs: document backup API #PSBM-124261
- vzct: Support setting memory guarantee for active CT #PSBM-122518
- vzct: Support setting IO limits for active CT #PSBM-122519
- tools: treat 'in shutdown' etc as shutdown finished #VSTOR-37835
- qemu: don't error if cannot find disk by alias #PSBM-125811
- qemu: vcmmd support for setting balloon #PSBM-123145
- qemu: better cluster size for tmp deltas on vstorage migration #PSBM-123434
- util: add hanging process debugging #PSBM-126062
- vzct: Support disk resize for active CT #PSBM-122525
- qemu: detect block node names after attaching a disk #VSTOR-40911
- qemu/api: support min_guarantee as fraction of balloon #PSBM-126684
- security: don't restore labels for readonly and shared images on errors
- qemu: fix noisy error for domain with image on readonly FS
- misc: add blockjob type for block snapshot job #PSBM-126433
- qemu: monitor: add qemuMonitorBlockDirtyBitmapRemoveBusy
- util: add virTimeBackOffWaitUnlocked
- backup: qemu: retry bitmap deletion while it is used by nbd #PSBM-126896
- qemu: add qemuMonitorJSONBlockdevDelBusy
- backup: qemu: retry fleece node deletion while it is used by nbd
- vstorage migration: cleanup precreated src tmp deltas #PSBM-123432
- upgrade: drain chardev's pipes #PSBM-108071
- remote: remove unused daemonConfigLoadData
- util: move virConf definition to header
- util: make conf a linked list of configs
- util: add virConfReadDir to read dir of configs
- util: add virConfCheckDuplicates to check for duplicate entries
- remote: remove filename from config error reporting
- remote: read config from libvirtd.d/ too #PSBM-127469
- qemu: read config from qemu.d/ too #PSBM-127469
- security: handle chown EACCES on readonly cifs mount #PSBM-127546
- vzct: add ip address to venet0 schema
- vzct: dump ip info for interfaces #PSBM-106470
- vzct: support setting net interface ips on define
- FIXUP: upgrade: tap: use multiqueue to make upgrade possible
- qemu: acquire job to handle agent disconnection #PSBM-127753
- nwfilter: don't add symmetric record for policy rule #PSBM-126688
- qemu: notify vcmmd of node/vcpu pinning #PSBM-126679
- qemu: fix restoring label if usb hostdev is detached from host
- qemu: handle usb hostdev on qemu update #PSBM-97288
- qemu: handle timeout on unplugging device on qemu update
- storage: open code storageBackendRedoPloopUpdate
- storage: fix refreshing ploop volumes #PSBM-128810
- qemu: don't access vm without lock
- qemu: request flat block graph output when possible
- TMP: temporary fixes to unblock most of cases
- vzct: support cpumask configuration #PSBM-107822
- vzct: support numatune nodeset configuration #PSBM-107822
- vstorage pools: detect vstorage
- vstorage pools: use external metadata on pool refresh #PSBM-129099
- vstorage pools: use external metadata on volume refresh
- vstorage pools: save metadata on creating volume
- vstorage pools: update metadata on resizing volume
- vstorage volume: delete metadata on deleting volume
- vstorage pools: cleanup outdated metadata
- qemu: capabilities: Add capability for the 'copy-mode' arg of 'drive-mirror' command #PSBM-97507
- qemu: use write-blocking copy-mode for mirror commands #PSBM-97507
- qemu: don't prohibit of cdrom/floppy hot attach/detach #VSTOR-44342
- vzct: support user alias for devices #PSBM-130985
- MERGE: schema: snapshot: add persistent domain config
- conf: remove static from virDomainDefSetMetadata
- vzct: support getting/setting metadata #PSBM-131257
- qemu: add hook on define #PSBM-130792
- qemu: add virtuozzo specific hook on define
- qemu vz hook: set machine type q35
- vzct: support rename #PSBM-131350
- vstorage migration: support explicit backing
- FIXUP: qemu: extract private exec commands #PSBM-129743
- conf: add 'vz-dhcp' parameter to xml #PSBM-129743
- qemu: support setting net params thru prl_nettool #PSBM-129743
- qemu: keep 'netConfigApplied' in status file #PSBM-129743
- qemu: validate that route is default gateway #PSBM-129743
- qemu: vzhook: add windows tweaks #PSBM-130505 #PSBM-130504
- vstorage migration: handle tmp snapshot in qemuProcessFixNVRAMCopyJob
- qemu: support changing net params #PSBM-129743
- vzct 2: support volumes in define/undefine/stats #PSBM-128811
- vzct 2: support volumes on start/stop #PSBM-128811
- vzct 2: store disk uuids in snapshot metadata
- conf: virDomainSnapshotDefParse allow NULL @current
- vzct 2: support volumes for snapshot API #PSBM-128811
- vzct 2: add destination pool info to migration cookie
- vzct 2: migration: check storage pool alignment on src and dest
- vzct 2: support volumes on migration #PSBM-128811
- vzct 2: skip actions on libvzctl config after migration completed
- Save state of guest tools autoupdate in domain metadata #PSBM-129617
- qemu: fix refreshing of restored VM #PSBM-132173 [upstream]
- qemu: Save guest tools version to metadata #PSBM-132017
- qemu: add support for live changing of IP settings in guest #PSBM-129743
- vzct: use guest mac address as configuration parameter #PSBM-132339
- vzct: process dhcp/dhcp6 CT network parameter
- vzct 2: support VIR_DOMAIN_DESTROY_GRACEFUL flag #PSBM-132436
- Fixed x-block-snapshot-{create,delete} functionality #PSBM-132371
- Skip LC_ALL setting for "define" hooks #PSBM-132202
- qemu: fix events when destroy on reboot #PSBM-132238
- FIXUP: Fix fox multiple ip #PSBM-132727
- vircommand: fix checking mixing daemon and string output #PSBM-133499
- vzct: support virConnectGetHostname #PSBM-132591
- vzct: support virNodeGetInfo #PSBM-132592
- vzct: support virNodeGetCPUMap #PSBM-132594
- vzct: support virConnectGetVersion #PSBM-132593
- vzct: support misc undefine flags #PSBM-133506
- vzct: support managed save related API #PSBM-133505
- vzct: support misc cputune settings #PSBM-133494
- remote: log unix socket client command line #PSBM-133653
- conf: remove params we set in libvirtd.d and qemu.d #PSBM-133668
- Add description of vz-dns element #PSBM-131363
- vzct: add started hook #PSBM-133731
- vzct: support blkiotune/weight settings #PSBM-133495
- qemu: load bitmaps on disk hotplug #VSTOR-45545
- Add description of vz-dhcp subelement #PSBM-131363
- nwfilter: introduce method to utilize filters instantiation for particular vm #PSBM-133617
- vzct: add support for nwfilters instantiated after container configuration is complete #PSBM-133617
- vzct: support setting default gateway #PSBM-133497
- qemu: migration: check for blockjobs in qemu explicitly #PSBM-130479
- qemu: don't run direct monitor commands as query
- vzct: support for <vz-dns> section #PSBM-133621
- conf: make virDomainDiskInsertPreAlloced return insert position
- vzct: support attaching disks #PSBM-133912
- vzct: support attaching net interface
- vzct: support detaching disks #PSBM-133912
- vzct: support detachings nets
- qemu: add support for tune-guest-x event #PSBM-134079
- vzct: support virDomainUpdateDeviceFlags #PSBM-134064
- vzct: add libosinfo library to the driver build
- vzct: show/set ostemplate in libosinfo metadata #PSBM-134157
- vzct: support openvswitch interface-id #PSBM-134313
- remote: handle vcmmd commands in a priority threads #PSBM-134035
- qemu: disable nbd reconnect on migration #PSBM-134477
- qemu: allow attaching cdroms with empty source #PSBM-131794
- vzct: support vzctDomainSetUserPassword #PSBM-134928
- Adding support of network classes to libvirt #PSBM-134681
- Adding support of network classes to vzct #PSBM-134681
- tools: fix nsslinktest build in vz9
- vzct: don't create .libvirt subdir in CT private if it does not exist #PSBM-135245
- qemu: support for network traffic shaping by nft #PSBM-134894
- conf: make virDomainDefSaveXML public
- conf: allow VIR_DOMAIN_DEF_FORMAT_DISK_PRIVATE for virDomainDefFormat
- vzct: support migrating with chaning active/inactive config #PSBM-135596
- vzct: check changes in active/inactive xml are supported on migration
- upgrade: notify vcmmd of qemu binary update #PSBM-136407
- FIXUP: fix parsing block export conf typo
- FIXUP: fix typo in hub patch
- vz: fix compiler errors on vz9

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 7.6.0-2
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Wed Aug  4 2021 Jiri Denemark <jdenemar@redhat.com> - 7.6.0-1
- Rebased to libvirt-7.6.0 (rhbz#1950948)
- The rebase also fixes the following bugs:
    rhbz#1986509, rhbz#1984318, rhbz#1810661, rhbz#1977776, rhbz#1948433
    rhbz#1978526, rhbz#1976690

* Wed Jul 14 2021 Jiri Denemark <jdenemar@redhat.com> - 7.5.0-1
- Rebased to libvirt-7.5.0 (rhbz#1950948)
- The rebase also fixes the following bugs:
    rhbz#1949388, rhbz#1969354, rhbz#1970277, rhbz#1972145, rhbz#1973094
    rhbz#1975071, rhbz#1972468, rhbz#1975677

* Mon Jun  7 2021 Jiri Denemark <jdenemar@redhat.com> - 7.4.0-1
- Rebased to libvirt-7.4.0 (rhbz#1950948)
- The rebase also fixes the following bugs:
    rhbz#1960993

* Mon May 24 2021 Jiri Denemark <jdenemar@redhat.com> - 7.3.0-1
- Rebased to libvirt-7.3.0 (rhbz#1950948)
- The rebase also fixes the following bugs:
    rhbz#1898526, rhbz#1910617, rhbz#1910618, rhbz#1943392, rhbz#1946918
    rhbz#1947718, rhbz#1947720, rhbz#1947824, rhbz#1949342, rhbz#1950228
    rhbz#1950301, rhbz#1950601, rhbz#1950948, rhbz#1953939, rhbz#1958302
    rhbz#1962053
- RHEL: Enable usage of x-blockdev-reopen (rhbz#1953939)
- RHEL: Add gating.yaml for RHEL9 (rhbz#1950601)

* Thu Apr 22 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-6
- spec: Do not build qemu driver for Power on RHEL-9 (rhbz#1946529)

* Fri Apr 16 2021 Mohan Boddu <mboddu@redhat.com> - 7.0.0-5
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Wed Feb 03 2021 Cole Robinson <aintdiscole@gmail.com> - 7.0.0-4
- Increase meson test timeout to fix builds on s390x copr

* Tue Feb 02 2021 Laine Stump <laine@redhat.com> - 7.0.0-3
- disable netcf in build

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 15 2021 Daniel P. Berrangé <berrange@redhat.com> - 7.0.0-1
- Rebase to 7.0.0 release

* Fri Dec 04 2020 Cole Robinson <aintdiscole@gmail.com> - 6.10.0-2.1
- Rebuild for wireshark soname bump

* Fri Dec 04 2020 Richard W.M. Jones <rjones@redhat.com> - 6.10.0-2
- Build libvirt-daemon-kvm for riscv64.

* Tue Dec 01 2020 Cole Robinson <crobinso@redhat.com> - 6.10.0-1
- Update to version 6.10.0

* Wed Nov  4 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.9.0-2
- Re-apply reverted fix for disabling glusterfs, curl, openswman and libiscsi

* Tue Nov 03 2020 Cole Robinson <crobinso@redhat.com> - 6.9.0-1
- Update to version 6.9.0

* Mon Nov  2 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.8.0-4
- Really fix meson option for disabling glusterfs
- Fix disabling curl, openswman and libiscsi

* Mon Nov  2 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.8.0-4
- Fix name of meson option for disabling glusterfs

* Fri Oct 30 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.8.0-3
- Fix stat() mocking for new glibc

* Wed Oct 28 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.8.0-2
- Remove obsolete bash_completion conditional
- Pass args to meson based on with_libssh/with_libssh2

* Thu Oct 01 2020 Cole Robinson <crobinso@redhat.com> - 6.8.0-1
- Update to version 6.8.0

* Fri Sep  4 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.7.0-2
- Fix QEMU start when KVM is not loaded (rhbz#1875327)

* Tue Sep 01 2020 Cole Robinson <crobinso@redhat.com> - 6.7.0-1
- Update to version 6.7.0

* Fri Aug 21 2020 Merlin Mathesius <mmathesi@redhat.com> - 6.6.0-3
- Fix so no platforms depend upon ceph for 32-bit architectures
- Include upstream patches to fix GCC 10 warnings

* Fri Aug 21 2020 Daniel P. Berrangé <berrange@redhat.com> - 6.6.0-2
- Fix creation of pools on non-btrfs (rhbz#1870197)

* Tue Aug 04 2020 Cole Robinson <crobinso@redhat.com> - 6.6.0-1
- Update to version 6.6.0

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jul 03 2020 Cole Robinson <crobinso@redhat.com> - 6.5.0-1
- Update to version 6.5.0

* Tue Jun 02 2020 Cole Robinson <crobinso@redhat.com> - 6.4.0-1
- Update to version 6.4.0

* Tue May 05 2020 Cole Robinson <crobinso@redhat.com> - 6.3.0-1
- Update to version 6.3.0

* Thu Apr 02 2020 Cole Robinson <crobinso@redhat.com> - 6.2.0-1
- Update to version 6.2.0

* Tue Mar 24 2020 Felipe Borges <feborges@redhat.com> - 6.1.0-2
- Check for disk type correctly in virDomainDiskTranslateSourcePool

* Wed Mar 04 2020 Cole Robinson <crobinso@redhat.com> - 6.1.0-1
- Update to version 6.1.0

* Tue Feb 25 2020 Cole Robinson <crobinso@redhat.com> - 6.0.0-3
- Rebuild for libiscsi soname bump

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jan 15 2020 Cole Robinson <crobinso@redhat.com> - 6.0.0-1
- Update to version 6.0.0
